#ifndef NLIB_H
#define NLIB_H
/* -------------------------------------------------------------------- */
/* File:     nlib.h 
/* -------------------------------------------------------------------- */

/* Description: Define symbolic constants, data types, macros, and  
                function prototypes for functions in NLIB. */

/* ------------------------------------------------------------------- */
/* Select precision */
/* ------------------------------------------------------------------- */

#define SINGLE    0                         /*  7 digits */
#define DOUBLE    1                         /* 16 digits */

#define PRECISION SINGLE
#if   PRECISION == SINGLE
   #define  INFINITY  FLT_MAX 
#elif PRECISION == DOUBLE                  
   #define  float  double
   #define  INFINITY  DBL_MAX
#endif

/* ------------------------------------------------------------------- */
/* Function macros */
/* ------------------------------------------------------------------- */

#define MIN(x,y) ((x) < (y) ? (x) : (y))
#define MAX(x,y) ((x) > (y) ? (x) : (y))
#define SGN(x)   ((x) < 0   ? -1  : 1)

/* ------------------------------------------------------------------- */
/* Function prototypes: ANSI C library */
/* ------------------------------------------------------------------- */

#include <math.h>
#include <stdio.h>		
#include <stdlib.h>		
#include <string.h>
#include <time.h>
#include <float.h>
#include <ctype.h>

/* ------------------------------------------------------------------- */
/* Symbolic constants */
/* ------------------------------------------------------------------- */

#define  COMPILER   1              /* 0=Turbo C,1=Borland C,2=Quick C */
#define  PI         3.141592654f   /* unit circle area */
#define  LRAND_MAX  2147483647L	   /* maximum random integer */
#define  UP         72             /* up arrow */
#define  DOWN       80             /* down arrow */
#define  LEFT       75             /* left arrow */
#define  RIGHT      77             /* right arrow */	
#define  ESC        27             /* escape key */
#define  CR         13             /* carriage return */
#define  BK         8              /* backspace */
#define  NE         191            /* northeast corner */
#define  NW         218            /* northwest corner */
#define  SW         192            /* southwest corner */
#define  SE         217            /* southeast corner */	
#define  Right      180            /* right intersection */	 		
#define  Left       195            /* left intersection */ 
#define  Top        194            /* top intersection */
#define  Bottom     193            /* bottom intersection */
#define	 VBAR       179            /* vertical bar */
#define  HBAR       196            /* horizontal bar */
#define  BAR        '|'            /* VBAR for printer */
#define  DASH       '-'            /* HBAR for printer */

/* ------------------------------------------------------------------- */
/* Public data types */
/* ------------------------------------------------------------------- */

typedef struct {			
   float        x;                   /* real part */
   float        y;                   /* imaginary part */
} complex;

typedef float*    vector;            /* real vector */	 	
typedef vector*   matrix;            /* real matrix */
typedef complex*  cvector;           /* complex vector */ 
typedef cvector*  cmatrix;           /* complex matrix */
typedef char*     string;            /* string of characters */
typedef string*   svector;           /* vector of strings */ 

/* ------------------------------------------------------------------- */
/* NLIB Core: nlib.c                                        (Appendix) */
/* ------------------------------------------------------------------- */

void    nerror 	  (int k,char *s,int i,float x,char *q);
vector  vec       (int n,char *s);		 	
vector  randvec   (int n,float a,float b);
cvector cvec      (int n,char *s);
void    freevec   (vector x);
void    freecvec  (cvector x);
void    zerovec   (vector x,int n);
void    copyvec   (vector x,int n,vector y);

matrix  mat       (int m,int n,char *s);
matrix  randmat   (int m,int n,float a,float b);
cmatrix cmat      (int m,int n,char *s);
void    freemat   (matrix A,int m);
void    freecmat  (cmatrix A,int m);
void    zeromat   (matrix A,int m,int n);
void    copymat   (matrix A,int m,int n,matrix B);

void	putvec	  (vector x,int n,char *vname,char *fname,int mode);
vector  getvec    (FILE *f,int *n);
void	putcvec   (cvector x,int n,char *vname,char *fname,int mode);
cvector getcvec   (FILE *f,int *n);

void	putmat	  (matrix A,int m,int n,char *vname,char *fname,int mode);
matrix  getmat    (FILE *f,int *m,int *n);
void	putcmat   (cmatrix A,int m,int n,char *vname,char *fname,int mode);
cmatrix getcmat   (FILE *f,int *m,int *n);
void    getcol    (matrix A,int m,int n,int c,vector x);
void    putcol    (matrix A,int m,int n,int c,vector x);
void    add_m     (char *s,char *r);

void    transpose (matrix A,int m,int n,matrix B);
float   inner     (vector x,vector y,int n);
void    outer     (vector x,vector y,int n,matrix A);
void    vecmat    (vector x,matrix A,int m,int n,vector b);
void    matvec    (matrix A,vector x,int m,int n,vector b);
void    matmat    (matrix A,matrix B,int m,int n,int p,matrix C);
float   minvec    (vector x,int n,int *k);
float   maxvec    (vector x,int n,int *k);
float   minmat    (matrix A,int m,int n,int *k,int *j);
float   maxmat    (matrix A,int m,int n,int *k,int *j);

complex	cnum      (float x,float y);
complex	cadd      (complex u,complex v);
complex	csub      (complex u,complex v);
complex	cmul      (complex u,complex v);
complex	cdiv      (complex u,complex v);
float   cmag      (complex u);
float   cphi      (complex u);
complex	csqrt     (complex u);
complex	cexp      (complex u);
complex cpoly     (complex u,vector a,int n);
void    csort     (cvector x,int n);

void    randinit  (long s);
float   randu     (float a,float b);
float   randg     (float m,float s); 

float   args      (float x,float a,float b,int k,char *f);
float   epsilon   (void);
void    dec2bin   (unsigned x,char *b);
int     scanline  (FILE *f,char c,char *s);
float   polynom   (float x,vector a,int n);
float   vecnorm   (vector x,int n);

/* ------------------------------------------------------------------- */
/* Linear algebraic systems: linear.c                      (chapter 2) */
/* ------------------------------------------------------------------- */

float   lufac     (matrix A,int n,matrix Q,vector p);
int     lusub     (matrix Q,vector p,vector b,int n,vector x);
int     ludec     (matrix A,vector b,int n,vector x);
float   det       (matrix A,int n);
float   inv       (matrix A,int n,matrix B);
float   condnum   (matrix A,int n,int m);
float   residual  (matrix A,vector b,vector x,int n);
int     sr        (vector x,matrix A,vector b,float alpha,float eps,
                   int n,int m);
float   tridec    (matrix T,vector b,int n,vector x);
int 	gensys 	  (matrix A,vector b,int m,int n,vector x);
int 	geninv 	  (matrix A,int m,int n,matrix B);

/* ------------------------------------------------------------------- */
/* Eigenvalues and eigenvectors: eigen.c                   (chapter 3) */
/* ------------------------------------------------------------------- */

void    leverrier  (matrix A,int n,vector a);
int     powereig   (matrix A,int n,float eps,int m,int d,float *c,
                    vector x);
void    house      (matrix A,int n,matrix B,matrix Q);
int     jacobi     (matrix A,int n,int m,float eps,vector c,matrix X);
int     qr         (matrix A,int n,int m,float eps,cvector c);
int     danilevsky (matrix A,int n,int m,float eps,cvector c,cmatrix X);
int 	roots      (vector a,float eps,int n,int m,cvector x);

/* ------------------------------------------------------------------- */
/* Curve fitting: curves.c                                 (chapter 4) */
/* ------------------------------------------------------------------- */

float  piece   (float a,vector x,vector y,int n);
float  spline  (float a,vector x,vector y,vector c,int n,int ic);
float  polyfit (float a,vector x,vector y,vector w,matrix A,int n,
                int m,int ic);
float  bilin   (float a,float b,vector x,vector y,matrix Z,int m,int n);
void   smooth  (vector x,vector y,int n,int m,vector z);

/* ------------------------------------------------------------------- */
/* Root finding: roots.c                                   (chapter 5) */
/* ------------------------------------------------------------------- */

int     bisect   (float x0,float x1,float eps,int m,float *x, 
                  float (*f)(float x));
int     secant   (float x0,float x1,float eps,int m,float *x,
                  float (*f)(float x));
int     muller   (complex x0,complex x1,complex x2,float eps,
                  int m,complex *x,complex (*f)(complex x));
int     newton   (vector x,float eps,int n,int m,
                  void (*f)(vector x,int n,vector y),
                  void (*g)(vector x,int n,matrix J));
int     laguerre (complex x0,float eps,int m,vector a,int n,complex *x);
int     polyroot (vector a,float eps,int n,int m,cvector x);

/* ------------------------------------------------------------------- */
/* Optimization: optim.c                                   (chapter 6) */
/* ------------------------------------------------------------------- */

int     conjgrad (vector x,float eps,int n,int m,
                  int v,int *ev,float (*f)(vector x,int n),
                  void (*g)(vector x,int t,vector df));
int     dfp      (vector x,float eps,int n,int m,
                  int v,int *ev,float (*f)(vector x,int n),
                  void (*g)(vector x,int t,vector df));
int     penalty  (vector x,float eps,float mu,int n,int r,int s,
                  int m,int *ev,float (*f)(vector x,int n),
                  void (*p)(vector x,int n,int r,vector y),
                  void (*q)(vector x,int n,int s,vector y));
int     anneal   (vector x,float f0,float f1,float eps,float eta,
                  float gamma,float mu,int n,int m,vector a,
                  vector b,int *ev,float (*f)(vector x,int n));

/* ------------------------------------------------------------------- */
/* Numerical derivatives and integrals: integ.c            (chapter 7) */
/* ------------------------------------------------------------------- */

float  deriv     (float a,float h,int n,int m,int e,
                  float (*f)(float x));
float  trapint   (float a,float b,int n,float (*f)(float x));
float  simpson   (float a,float b,int n,float (*f)(float x));
float  midpoint  (float a,float b,int n,float (*f)(float x));
float  romberg   (float a,float b,float eps,int m,int *r,
                  float (*f)(float x));
float  gaussquad (float a,float b,int n,float (*f)(float x));
float  monte     (vector a,vector b,int m,int n,
                  float (*f)(vector x,int m));

/* ------------------------------------------------------------------- */
/* Ordinary differential equations: ode.c                  (chapter 8) */
/* ------------------------------------------------------------------- */

long    rkf     (vector x0,float t0,float t1,int n,int m,
                 float eps,long q,vector t,matrix X,float *e,
                 void (*f)(float t,vector x,int n,vector dx));
long    bsext   (vector x0,float t0,float t1,int n,int m,
                 float eps,long q,vector t,matrix X,float *e, 
                 void (*f)(float t,vector x,int n,vector dx));
long    stiff   (vector x0,float t0,float t1,int n,int m,
                 float eps,long q,vector t,matrix X,float *e,   
                 void (*f)(float t,vector x,int n,vector dx),
                 void (*fx)(float t,vector x,int n,matrix J),
                 void (*ft)(float t,vector x,int n,vector y));
int     bvp     (float alpha,float beta,float a,float b,float eps,
                 int m,int q,vector t,vector y,float *e,
                 float (*g)(float t,float y,float dy));

/* ------------------------------------------------------------------- */
/* Partial differential equations: pde.c                  (chapter 9) */
/* ------------------------------------------------------------------- */

int     poisson (float a,float b,int m,int n,int q,float eps,float *alpha,
                 vector x,vector y, matrix U,float (*f)(float x,float y),
                 float (*g)(float x,float y));
void    heat1   (float T,float a,int m,int n,float beta,float c1,float c2,
                 vector t,vector x,matrix U,float (*f)(float x),
                 float (*g)(float t,int k));
void    heat2   (float T,float a,float b,int m,int n,int p,
                 float beta,vector x,vector y,matrix U,
                 float (*f)(float x,float y),
                 float (*g)(float t,float x,float y));
void    wave1   (float T,float a,int m,int n,float beta,vector t,
                 vector x,matrix U,float (*f)(float x),
                 float (*g)(float x));
void    wave2   (float T,float a,float b,int m,int n,int p, 
                 float beta,vector x,vector y,matrix U,
                 float (*f)(float x,float y),
                 float (*g)(float x,float y));

/* ------------------------------------------------------------------- */
/* Digital signal processing: dsp.c                       (chapter 10) */
/* ------------------------------------------------------------------- */

void   dft      (cvector z,int n,int d);
void   dft2     (cmatrix Z,int m,int n,int d);
void   spectra  (vector x,int n,float fs,vector A,vector phi,vector f);
void   crosscor (vector x,vector y,int n,int m,vector rho);
void   convolve (vector x,vector y,int n,vector z);
void   fir      (float (*g)(float f),int p,vector b);
void   freqrsp  (vector u,vector y,int n,float fs,vector A,
                 vector phi,vector f);
float  arma     (float u,vector theta,vector x,int n,int m);
float  getarma  (vector u,vector y,int p,int n,int m,vector theta);
float  lms      (float u,float y,vector x,vector theta,float mu,int m);

/* ------------------------------------------------------------------- */
/* Tabular display support: show.c                          (Appendix) */
/* ------------------------------------------------------------------- */

void    shownum    (char *s,float q);
void    showvec    (char *s,vector x,int n,int t);
void    showmat    (char *s,matrix A,int m,int n,int t);
void    showcnum   (char *s,complex u);
void    showcvec   (char *s,cvector x,int n,int t);
void    showcmat   (char *s,cmatrix A,int m,int n,int t);
float   prompt     (char *s,float a,float b,float df);
void    wait       (void);

void    listnum    (char *s,float z);
void    listvec    (char *s,vector x,int n,int t);
void    listmat    (FILE *dev,char *s,matrix A,int m,int n,int t);
void    listcnum   (char *s,complex z);
void    listcvec   (char *s,cvector x,int n,int t);
void    listcmat   (FILE *dev,char *s,cmatrix A,int m,int n,int t);

/* ------------------------------------------------------------------- */
/* Graphical display support: draw.c                        (Appendix) */
/* ------------------------------------------------------------------- */

void 	graphvec (vector y,int n,char *title,char *xaxis,
                  char *yaxis,char *fname);
void 	graphmat (matrix Y,int m,int n,char *title,char *xaxis,
                  char *yaxis,char *fname);
void 	graphfun (float a,float b,char *title,char *xaxis,
                  char *yaxis,float (*f)(float x),char *fname);
void 	graphxy (vector x,vector y,int n, char *title,
                 char *xaxis,char *yaxis,char *fname);
void 	graphxm (vector x,matrix Y,int m,int n, char *title,
                 char *xaxis,char *yaxis,char *fname);
void 	graphmm (matrix X,matrix Y,int m,int n,char *title,
                 char *xaxis,char *yaxis,char *fname,int dm);

void 	plotmat (matrix Z,int m,int n,char *title,char *xaxis,
                 char *yaxis,char *zaxis,char *fname);

void 	plotfun (float x0,float x1,float y0,float y1,
                 char *title,char *xaxis,char *yaxis,
                 char *zaxis,float (*f)(float x,float y),
                 char *fname);
void    plotxyz (vector x,vector y,matrix Z,int m,int n,char *title,
                 char *xaxis,char *yaxis,char *zaxis, char *fname);

/* ------------------------------------------------------------------- */
/* Low-level funtions                                                  */
/* ------------------------------------------------------------------- */
                 
int    pause     (char *s);
void   remarks   (FILE *f,char *c);
void   putstr0   (char *s,char *fname,int mode);
void   putstr1   (char *title,char *xaxis,char *yaxis,char *fname);
void   putstr2   (char *title,char *xaxis,char *yaxis,char *zaxis,
                  char *fname);
void   addlabel  (float x,float y,char *label,char *fname);
int    scalemat  (matrix A,int m,int n);
float  matnorm   (matrix A,int n);
float  orthpoly  (float x,matrix A,int m,int k);
float  syndiv    (vector a,float c,int n,vector b);
void   syndiv2   (vector a,float p,float q,int n,vector b,float *r,
                  float *s);
void   Jacobian  (vector x,int n,matrix J,
                  void (*f)(vector x,int n,vector y));
void   quadratic (vector a, cvector x);
int    falsepos  (float x0,float x1,float eps,int m,float *x, 
                  float (*f)(float x));
int    aitken    (float x0,float b,float eps,int m,int ex,float *x,
                  float (*f)(float x));
int    Newton1   (float x0,float eps,int m,float *x,
                  float (*f)(float x,int k));
int    bracket   (float h,vector x,vector d,float mu,int n,int r,
                  int s,float *a,float *b,float *c,int *err,
                  float (*f)(vector x,int n),
                  void (*p)(vector x,int n,int r,vector y),
                  void (*q)(vector x,int n,int s,vector y));
int    golden    (vector x,vector d,float a,float c,float eps,
                  float mu,int n,int r,int s,float *h,
                  float (*f)(vector x,int n),
                  void (*p)(vector x,int n,int r,vector y),
                  void (*q)(vector x,int n,int s,vector y));
int    bisectd   (vector x,vector d,float a,float c,float eps,
                  float mu,int n,int r,int s,float *m,
                  float (*f)(vector x,int n),
                  void (*g)(vector x,int n,vector df),
                  void (*p)(vector x,int n,int r,vector y),
                  void (*q)(vector x,int n,int s,vector y));
float  deriv2    (float a,float h,int p,int m,int e,float (*f)(float x));
float  rkfstep   (vector x0,float t0,float t1,int n,vector x1,
                  void (*f)(float t,vector x,int n,vector dx));
long   rkf0      (vector x,float t0,float t1,int n,float eps,long q,
                  float *e,void (*f)(float t,vector x,int n,vector dx));
long   bsext0    (vector x,float t0,float t1,int n,float eps,long q,
                  float *e,void (*f)(float t,vector x,int n,vector dx));
long   stiff0    (vector x,float t0,float t1,int n,float eps,long q,float *e,   
                  void (*f)(float t,vector x,int n,vector dx),
                  void (*fx)(float t,vector x,int n,matrix dfdx),
         	  void (*ft)(float t,vector x,int n,vector dfdt));
double trifac    (matrix T,int n,matrix Q);
double trisub    (matrix Q,vector b,int n,vector x);

#endif
