     /*------------------------------------------------------------------*/
     /* Example a2.10.1: Unconstrained Optimization */
     /*------------------------------------------------------------------*/
     #include "c:\nlib\util.h"

     #define   M 100                         /* number of data points */
     float     t[M+1],                       /* independent variables */  
               y[M+1];                       /* dependent variables */

     float F (float t,vector q,int n)        /* curve fit function */
     {
        float 	a,b=10;
        a = MIN (b,MAX(-b,-q[2]*t));
        return (q[1]*exp(a) + q[3]);
     }
   
     float f (vector x,int n)                /* objective function */
     {
        int 		i;
        float	z = 0;
        for (i = 1; i <= M; i++) 
           z += pow(F(t[i],x,n)-y[i],2);
        return z/M;
     }

     int main (void)
     {
        int          n = 3,                  /* number of variables */
                     m = 250,                /* maximum iterations */ 
                     i,ev;
        float        tol = 1.0e-3,           /* error tolerance */
                     T = 5,                  /* range of t */  
                     s = 0.2;                /* standard deviation */
        vector       q = vec (3,"6,0.5,2"),  /* nominal parameters */
                     x =  vec(n,"");                
        matrix       Y = mat (3,M,""); 

     /* Construct data */

        printf ("\nExample A2.10.1: Unconstrained Optimization\n");
        for (i = 1; i <= M; i++)
        {
           t[i] = (i-1)*T/(M-1);
           y[i] = F(t[i],q,n) + randg(0,s);
           Y[3][i] = y[i];
        }
   
     /* Curve fit parameters: conjugate-gradient */
      
        i = conjgrad (x,tol,n,m,n,&ev,f,NULL);
        printf ("\nConjugate gradient iterations = %i.",i);
        printf ("\nFunction evaluations = %i.",ev);
        printf ("\nOptimal x = [%.7f, %.7f, %.7f]^T",x[1],x[2],x[3]);
        printf ("\nf(x) = %.7f\n",f(x,n));
        for (i = 1; i <= M; i++)
           Y[1][i] = F(t[i],x,n);

     /* Curve fit parameters: DFP */

        zerovec (x,n);
        i = dfp (x,tol,n,m,n,&ev,f,NULL);
        printf ("\nDFP iterations = %i.",i);
        printf ("\nFunction evaluations = %i.",ev);
        printf ("\nOptimal x = [%.7f, %.7f, %.7f]^T",x[1],x[2],x[3]);
        printf ("\nf(x) = %.7f\n",f(x,n));

     /* Display curves and data */

        for (i = 1; i <= M; i++)
           Y[2][i] = F(t[i],x,n);
        graphxm (t,Y,3,M,"Unconstrained Optimization","t","y","figa2101");
        wait();
        return 0;
     }
     /*------------------------------------------------------------------*/


