     /*------------------------------------------------------------------*/
     /* Example a2.12.1: The van der Pol Oscillator */
     /*------------------------------------------------------------------*/
     #include "c:\nlib\util.h"

     void vanderPol (float t,vector x,int n,vector dx)
     {
     /* Description: van der Pol Oscillator */

        float    mu = 2;
        dx[1] =  x[2];
        dx[2] = -x[1] + mu*(1 - x[1]*x[1])*x[2];
     }

     int main (void)
     {
        long         q       = 20000,                /* maximum evaluations */
                     r;                              /* function evaluations */
        int          n       = 2,                    /* system dimension */
                     m       = 500;                  /* solution points */
        float        alpha   = 0,                    /* initial time */
                     beta    = 30.0,                 /* final time */
                     tol     = 1.e-5,                /* error bound */
                     E;                              /* estimated error */
        vector       t       = vec (m,""),           /* solution times */
                     x0      = vec (n,"0.5 0"),      /* initial condition */
                     x1      = vec (n,"-1 2");       /* initial condition */
        matrix       X       = mat (2,m,""),         /* plot points x */
                     Y       = mat (2,m,""),         /* plot points y */
                     Z       = mat (n,m,"");         /* solution points */ 

     /* Solve system from x = x0 */

        printf ("\nExample A2.12.1: The van der Pol Oscillator\n");
        r = rkf (x0,alpha,beta,n,m,tol,q,t,Z,&E,vanderPol);
        shownum ("Number of scalar function evaluations",r);   
        shownum ("Maximum truncation error",E);
        copyvec (Z[1],m,X[1]);
        copyvec (Z[2],m,Y[1]);
   
     /* Solve system from x = x1 */

        r = bsext (x1,alpha,beta,n,m,tol,q,t,Z,&E,vanderPol);
        shownum ("Number of scalar function evaluations",r);   
        shownum ("Maximum truncation error",E);
        copyvec (Z[1],m,X[2]);
        copyvec (Z[2],m,Y[2]);

     /* Graph two solution trajectories */

        graphmm (X,Y,2,m,
                 "Limit Cycle of van der Pol Oscillator",
                 "x_1","x_2","figa2121",0);
        wait();
        return 0;
     }
     /*------------------------------------------------------------------*/
