/*----------------------------------------------------------------*/
/* Example 10.8.1: ARMA model                                     */
/*----------------------------------------------------------------*/

#include "c:\nlib\util.h"

int main (void)
{
   int          i,
		p = 512,
		n1 = 3,
                m1 = 3,
		n2 = 3,
		m2 = 3,
                r1 = n1 + m1 + 1,
                r2 = n2 + m2 + 1;
   float        fs = 1000,
		df = fs/p,
		e;
   vector	theta1 = vec (r1,"-.5 .6 -.3 1. -2. 8. -4."),
  		theta2 = vec (r2,""),
   		x1 = vec (r1,""),
   		x2 = vec (r2,""),
   		t = vec (p,""),
   		u = vec (p,""),
   		f = vec (p,"");
   matrix       Y = mat (2,p,""),
		A = mat (2,p,""),
		phi = mat (2,p,"");

/* Identify system */ 

   printf ("\nExample 10.8.1: ARMA Model\n");
   for (i = 1; i <= p; i++)
   {
      t[i] = i - 1; 	
      u[i] = randu (-1,1);
      Y[1][i] = arma (u[i],theta1,x1,n1,m1);
   }
   getarma (u,Y[1],p,n2,m2,theta2);
   for (i = 1; i <= MIN(r1,r2); i++)
   {
      e = 100*(theta2[i]-theta1[i])/theta1[i];	
      printf ("\n %i & %12.7f & %12.7f & %12.7f \\\\",i,theta1[i],
              theta2[i],e);
      if (i == n1)
         printf ("\n\\hline");
   }
      
/* Compare responses */
   
   zerovec (x1,r1);
   zerovec (x2,r2);
   for (i = 1; i <= p; i++)
   {
      if (i == 1)
         u[i] = 1;
      else
         u[i] = 0;
      Y[1][i] = arma (u[i],theta1,x1,n1,m1);
      Y[2][i] = arma (u[i],theta2,x2,n2,m2);
   }
   for (i = 1; i <= 2; i++)   
      freqrsp (u,Y[i],p,fs,A[i],phi[i],f);
   graphxm (f,A,2,p/2,"Magnitude Responses of System and ARMA Model",
            "f (Hz)","A(f)","fig1082");
   graphxm (f,phi,2,p/2,"Phase Responses of System and ARMA Model",
            "f (Hz)","\\phi(f)","fig1083");
   wait();
   return 0;
}
/*----------------------------------------------------------------*/
   


