/*----------------------------------------------------------------*/
/* Example 10.9.1: Heat Exchanger Frequency Response              */
/*----------------------------------------------------------------*/

#include "c:\nlib\util.h"

int main (void)
{
   int          n = 256,                /* number of samples */
		m,			/* time delay (samples ) */ 
		k;
   
   float	T = 0.25f,		/* sampling interval (min) */
   		fs = 1/T,		/* sampling rate (samples/min) */
		a = 10.0f,	        /* gain (deg C-m^3/min) */
		tau = 4.5f,		/* time constant (min) */
		Td = 1.5f,		/* time delay (min) */   		
		df;			/* frequency precesion */
		
   vector       u   = vec (n,"1"),      /* unit pulse input */
                y   = vec (n,""),       /* pulse response */
                A   = vec (n,""),       /* magnitude response */
                phi = vec (n,""),       /* phase response */
                t   = vec (n,""),       /* discrete times */	 
                f   = vec (n,"");       /* discrete frequencies */

/* Compute pulse response of heat exchanger */

   printf ("\nExample 10.9.1: Heat Exchanger Frequency Response\n");
   df = fs/n;
   m = (int) (Td/T + 0.5);
   for (k = 1; k <= n; k++)
   {
      t[k] = (k-1)*T;
      if (k > MAX(m+1,1))
         y[k] = y[k-1] + (T/tau)*(a*u[k-1-m] - y[k-1]);
   }

/* Compute and display frequency response */

   freqrsp (u,y,n,fs,A,phi,f);
   graphxy (f,A,n/2,
            "Magnitude Response of Glycol Hot Oil Heat Exchanger",
            "f (samples/min)","A(f)","fig1092");  
   wait();
   return 0;
} 
/*----------------------------------------------------------------*/



