/*--------------------------------------------------------------------*/
/* Example 10.9.4: Helicopter Noise                                   */
/*--------------------------------------------------------------------*/

#include "c:\nlib\util.h"

int main (void) {

   int          n = 1024,               /* number of samples */
                m = 3,                  /* number of harmonics */
                i,j;
   float        fs = 512.0f,            /* sampling frequency (Hz) */
                T = 1/fs,               /* sampling interval (sec) */
                blade = 32.0f,          /* blade passage frequency (Hz) */
                r  = 6.0f,              /* random noise magnitude */
                df = fs/n,
                b;
   vector       t   = vec (n,""),               /* time */
                x   = vec (n,""),               /* noise */ 	
                A   = vec (n,""),               /* magnitude */ 
                phi = vec (n,""),               /* phase */ 
                f   = vec (n,""),               /* frequency */
                a   = vec (m,"3.2 2.1 1.3"),    /* magnitudes */
                p   = vec (m,"1.8 -0.7 2.1");   /* phase angles */	
   		
/* Generate noise */   		
   		
   printf ("\nExample 10.9.4: Helicoptor Noise\n");
   for (i = 1; i <= n; i++)
   {
      t[i] = (i-1)*T;
      x[i] = randu(-r,r);
      for (j = 1; j <= m; j++)
      {
      	 b = j*2*PI*blade*(i-1)*T;
         x[i] += (float) (a[j]*cos(b + p[j]));
      }
   }
   graphxy (t,x,n,"Samples of Rotor Noise from Overhead Helicoptor",
            "t (sec)","x(t)","fig1096");

/* Convert from dB sound measurements to amplitude */

   for (i = 1; i <= n; i++)
      x[i] = (float) pow(10,x[i]/20);

/* Compute spectrum */

   spectra (x,n,fs,A,phi,f);
   A[1] = 0;				/* remove average value */
   graphxy (f,A,n/2,"Magnitude Spectrum of Helicoptor Noise",
            "f (Hz)","A(f)","fig1097");
   wait();
   return 0;
}
/*--------------------------------------------------------------------*/


