/* ------------------------------------------------------------------- */
/* Example 1.8.2: Monte Carlo Integration                              */
/* ------------------------------------------------------------------- */

#include "c:\nlib\util.h"

float f (float x)
{
   return x*log(1+x);
}	
   
int main (void)
{                              
    int    n    = 3000,         /* number of random points */
           a    = 0,            /* lower limit */
           b    = 1,            /* upper limit */   
           seed = 2000,         /* select random sequence */
           i;
    float  ye    = 0.25,        /* exact value of integral */
           z = 0,
           x,y;
    vector e = vec (n,"");      /* errors in estimates */       
              
 /* Estimate average value of f(x) with random numbers */

    printf ("\nExample 1.8.2: Monte Carlo Integration\n");
    randinit(seed);
    for (i = 1; i <= n; i++)
    {
       x = randu (a,b);
       z += f(x);
       y = (b-a)*z/i; 
       e[i] = y - ye;
    }
   
/* Display results */

    shownum ("Number of random points",n);
    shownum ("Final estimate of integral",y);
    graphfun (a,b,"Integrand","x","f(x)",f,"fig183");
    graphvec (e,n,"Error in Estimate","number of random points",
              "error","fig184");
    wait();
    return 0;
}
/* ------------------------------------------------------------------- */
