/* -------------------------------------------------------------- */
/* Example 3.9.1: Chemical Absorption Transients                  */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

int main (void)
{
   int          n = 4,                  /* number of stages */
                m = 500,                /* maximum iterations */
                i;
   float        a = 0.72f,              /* slope */	
                K = 1.63f,              /* gas to liquid ratio */ 
                tau = 1.86f,            /* stage liquid residence time */
                delta = a*K,            /* stripping factor */
                eps = 1.e-5f,           /* convergence threshold */
                p = 1.0f,               /* decay percentage */	
                t = 0.0f;
   vector       T = vec (n,"");         /* decay times */
   cvector      lambda = cvec (n,"");   /* eigenvalues */	
   matrix       A = mat (n,n,"");
   
/* Initialize A */

   printf ("\nExample 3.9.1: Chemical Absorption Transients\n");
   for (i = 1; i <= n; i++)
   {
      A[i][i] = -(1 + delta);
      if (i < n)
      {
         A[i][i+1] = 1;
         A[i+1][i] = delta;
      }
   }
   showmat ("A",A,n,n,0);
   
/* Find eigenvalues and decay times */

   shownum ("QR iterations",(float) qr(A,n,m,eps,lambda));
   showcvec ("Eigenvalues",lambda,n,0);
   for (i = 1; i <= n; i++)
      t += A[i][i] - lambda[i].x;
   shownum ("Trace check",(float) fabs(t)); 
   for (i = 1; i <= n; i++)
      T[i] = ((float) log(p/100))/lambda[i].x;
   showvec ("Decay times",T,n,0);
   return 0;   
}
/* -------------------------------------------------------------- */



