/* -------------------------------------------------------------- */
/* Example 3.9.2: Population Growth Model                         */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

int main (void)
{
   int          n = 5,			/* number of stages */
   		m = 500,		/* maximum iterations */
   		i;
   		
   float   	tol = 1.e-5f,		/* convergence threshold */
		lambda,			/* dominant eigenvalue */
		t;
		
   vector	alpha = vec (n,"1.1 1.5 2.2 2.7 1.3"),  /* birth vector */
		beta = vec (n,"0.4 0.1 0.1 0.5"),	/* death vector */
		x = vec (n,"");				/* eigenvector */
   
   matrix       A = mat (n,n,"");	/* growth coefficient matrix */
   
/* Initialize A */

   printf ("\nExample 3.9.2: Population Growth Model\n");
   for (i = 1; i <= n; i++)
   {
      A[1][i] = alpha[i];
      if (i < n)
         A[i+1][i] = beta[i];
   }
   showmat ("A",A,n,n,0);
   
/* Find dominant eigenvalue and eigenvector with power method */

   shownum ("Power iterations",(float) powereig(A,n,tol,m,1,&lambda,x));
   shownum ("Dominant eigenvalue",lambda);
   t = x[1];					/* normalize */
   if (fabs(t) > tol) 
      for (i = 1; i <= n; i++)
         x[i] /= t; 
   showvec ("Dominant eigenvector",x,n,0);
   return 0;
}
/* -------------------------------------------------------------- */



