/* -------------------------------------------------------------- */
/* Example 3.9.3: Telescope Position Control                      */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

int main (void)
{
   int          n = 3,                  /* order of system */
                m = 500,                /* maximum iterations */
                i,j;
   float        Ra = 10.0f,             /* armature resistance */
                La = 0.100f,            /* armature inductance */
                kb = 0.1f,              /* back emf constant */
                kt = 0.32f,             /* torque constant */
                b = 0.1f,               /* friction coefficient */
                J = 2.0f,               /* moment of inertia */
                eps = 1.e-5f,           /* convergence threshold */
                t = 0.0f;
   vector       kc = vec (3,"100 200 400"); /* controller gains */
   cvector      lambda = cvec (n,"");       /* eigenvalues */	
   matrix       A = mat (n,n,"");
   
/* Initialize A */

   printf ("\nExample 3.9.3: Telescope Position Control\n");
   A[1][2] = 1;
   A[2][2] = -b/J;
   A[2][3] = kt/J;
   A[3][2] = -kb/La;
   A[3][3] = -Ra/La;
   showmat ("A",A,n,n,0);
   
/* Find eigenvalues and oscillation frequencies */

   for (i = 1; i <= 3; i++)
   {
      A[3][1] = -kc[i]/La;
      shownum ("QR iterations",(float) qr(A,n,m,eps,lambda));
      showcvec ("Eigenvalues",lambda,n,0);
      t = 0;
      for (j = 1; j <= n; j++)
         t += A[j][j] - lambda[j].x;
      shownum ("Trace check",(float) fabs(t));
   }
   return 0;
}
/* -------------------------------------------------------------- */



