/* -------------------------------------------------------------- */
/* Example 4.7.1: Pressure-Temperature Curves */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

int main (void)
{
   int          n = 11,			/* number of data points */
                q = 10*n,		/* number of plot points */	
                m = 4,			/* number of coefficients */
                i,j,k;

   float	f = 1.e5f,		/* conversion factor */ 
		vg = 1.673f,		/* specific volume (gas) */
		vf = 0.00104f,		/* specific volume (liquid) */
		dh, 			/* change in enthalpy */
		s;			/* slope dp/DT */	
   
   vector       T = vec (n,"50 60 70 80 90 100 110 120 130 140 150"),
                p = vec (n,".1235 .1994 .3119 .4739 0.7014 1.014 "
                             "1.433 1.958 2.701 3.613 4.758"),
                a = vec (m,""),
		b = vec (m,""),             
		d = vec (m-1,"");

   matrix       C = mat (m,m,""),
		X = mat (2,q,""),
                Y = mat (2,q,"");
   
/* Find least-squares polynomial using equations (4.5.9)-(4.5.10) */

   printf ("\nExample 4.7.1: Pressure-Temperature Curves\n");
   for (k = 1; k <= m; k++)
   {
      for (i = 1; i <= n; i++)	
         b[k] += (float) pow(T[i],k-1)*p[i];
      for (j = 1; j <= m; j++)
         for (i = 1; i <= n; i++)
            C[k][j] += (float) pow(T[i],k+j-2);
   }
   ludec (C,b,m,a);

/* Find slope at T = 100 */   
   
   showvec ("Polynomial coefficients",a,m,0);
   for (i = 1; i < m; i++)
      d[i] = i*a[i+1];
   showvec ("Derivative coefficients",d,m-1,0);
   s = polynom (100,d,m-2);
   shownum ("Slope (bars/K)",s);

/* Find change in enthalpy */

   dh = 373.15f*(vg - vf)*(f*s);
   shownum ("Change in enthalpy (kJ/kg)",dh/1000);

/* Plot curve and data */
   
   for (i = 1; i <= q; i++)
   {
      j = MIN (i,n);
      X[1][i] = T[1] + (T[n] - T[1])*(i-1)/(q-1);
      Y[1][i] = polynom (X[1][i],a,m-1);
      X[2][i] = T[j];
      Y[2][i] = p[j];
   }
   graphmm (X,Y,2,q,"Pressure-Temperature Curve",
            "T (^oC)","p (bars)","fig471",1);
   wait();
   return 0;
}
/* -------------------------------------------------------------- */

