/*------------------------------------------------------------------*/
/* Example 5.8.1: Newton's vector method */
/*------------------------------------------------------------------*/
#include "c:\nlib\util.h"

void f(vector x,int n,vector y)
{
/* Description: Compute the n by 1 vector y  = f(x) given the n by 1
                vector x */

   y[1] = exp(2*x[1]) - x[2] - 4;
   y[2] = x[2] - x[3]*x[3] - 1;
   y[3] = x[3] - sin(x[1]);
}
   
void g(vector x,int n,matrix J)
{
/* Description: Compute the n by n Jacobain matrix J(x) given the
                n by 1 vector x. */

   J[1][1] = 2*exp(2*x[1]);
   J[1][2] = -1;
   J[1][3] = 0;

   J[2][1] = 0;
   J[2][2] = 1;
   J[2][3] = -2*x[3];

   J[3][1] = cos(x[1]);
   J[3][2] = 0;
   J[3][3] = 1;
}

int main (void)
{
   int		n = 3,
		m = 100,
		i,j;
   float	eps = 1.e-6;
   vector       x = vec (n,""),
		y  = vec (n,"");

   printf ("\nExample 5.8.1: Newton's Vector Method\n");
   i = newton (x,eps,n,m,f,g);
   printf ("\n\nx = [");
   for (j = 1; j < n; j++)
      printf ("%.7f, ",x[j]);
   printf ("%.7f]",x[n]);
   f(x,n,y);
   printf ("\n||f(x)|| = %.7f",vecnorm(y,n));
   printf ("\nExact Jacobian iterations = %i\n",i);

   zerovec (x,n);
   i = newton (x,eps,n,m,f,NULL);
   printf ("\n\n x = [");
   for (j = 1; j < n; j++)
      printf ("%.7f, ",x[j]);
   printf ("%.7f]",x[n]);
   f(x,n,y);
   printf ("\n||f(x)|| = %.7f",vecnorm(y,n));
   printf ("\nNumerical Jacobian iterations = %i\n",i);
   wait();
   return 0;
}
/*------------------------------------------------------------------*/


