/*--------------------------------------------------------------------*/
/* Example 5.9.1: Propane Cylinder                                    */
/*--------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float f (float v) 			/* bisection, secant */
{	
/* Redlich-Kwong equation of state */

   float        R = 0.08314f,   /* universal gas constant (bar-m^3/kmol-K) */
                T = 393.15f,    /* temperature (K) */
                a = 182.23f,    /* bar-m^6K^.5/kmol^2 */
                b = 0.06242f,   /* m^3/kmol */
                p = 30.0f,
                q;

   q = R*T/(v - b) - a/(v*(v + b)*((float) sqrt(T)));
   return p - q;
}

void g(vector x,int n,vector y)        /* Newton */
{
   y[1] = f(x[1]);
}
   
int main (void)
{
   int          r = 100,          /* maximum iterations */
                n = 1,            /* number of equations */
                i;                /* number of iterations */	
   float        v0 = 0.1f,        /* lower bound (must be > 0) */
                v1 = 0.9130f,     /* upper bound, initial guess */	
                eps = 1.e-6f,     /* error tolerance */
                M = 44.09f,       /* kg/kmol for propane */
                h = 1.35f,        /* height of cylinder (m) */
                d = 0.25f,        /* diameter of cylinder (m) */
                m = 2.9f,         /* mass of propane (kg) */	
                V_0,              /* exterior volume of cylinder */ 
                V_1,              /* interior volume of cylinder */
                A,                /* exterior surface area of cylinder */
                t,                /* wall thickness (m) */  
                v;
   vector       x = vec (n,"");   /* used by Newton */
                
/* Compute and display molar specific volume v */   

   printf ("\nExample 5.9.1: Propane Cylinder\n");
   printf ("\n------------------------------------------------");
   i = bisect (v0,v1,eps,r,&v,f);
   printf ("\nBisection: v = %.5f m^3/kmol, %2i iterations",v,i);
   i = secant (v0,v1,eps,r,&v,f);
   printf ("\nSecant:    v = %.5f m^3/kmol, %2i iterations",v,i); 
   x[1] = v0;
   i = newton (x,eps,n,r,g,NULL);
   printf ("\nNewton:    v = %.5f m^3/kmol, %2i iterations",x[1],i); 
   printf ("\n------------------------------------------------"); 

/* Compute cylinder volume and wall thickness */

   V_0 = PI*d*d*h/4;
   V_1 = m*v/M;
   shownum ("Exterior volume (m^3)",V_0);
   shownum ("Interior volume (m^3)",V_1);
   A = PI*d*h + 2*(PI*d*d/4);
   shownum ("Exterior surface area (m^2)",A);
   t = (V_0 - V_1)/A;
   shownum ("Wall thickness (cm)",100*t);
   return 0;
}
/*--------------------------------------------------------------------*/



