/*---------------------------------------------------------------------*/
/* Example 5.9.3: Industrial High-Temperature Oven                     */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

int main (void)
{
   int          m = 100,                /* maximum iterations */
                n = 4,                  /* polynomial degree */
                p = 200,                /* number of plot points */
                i;
   float        eps = 1.e-6f,           /* error tolerance */
                T = 293.15f,            /* ambient temperature (K) */
                u = 21.0f,              /* heater current */	
                alpha = 50.0f,
                beta = 2.0e-7f,
                gamma = 800.0f,
                xmin = 1000.0f,
                xmax = 1200.0f;
   vector       c = vec (n+1,""),       /* polynomial coefficients */
                x = vec (p,"");
   cvector      z = cvec (n,"");        /* polynomial roots */
   matrix       Y = mat (2,p,"");
	
/* Initialize coefficients */

   printf ("\nExample 5.9.3: Industrial High-Temperature Oven\n");
   c[1] = (float) (alpha*T + beta*pow(T,4) + gamma*pow(u,2));
   c[2] = -alpha;
   c[5] = -beta; 
   showvec ("Coefficients",c,n+1,0);

/* Display function */

   for (i = 1; i <= p; i++)
   {
      x[i]    = xmin + (i-1)*(xmax - xmin)/(p-1);
      Y[1][i] = polynom (x[i],c,n)/1000;
   }
   graphxm (x,Y,2,p,"The Oven Function",
            "x (^oK)","f(x)/1000","fig594");
  
/* Compute and display roots */
 
   i = polyroot (c,eps,n,m,z);
   shownum ("Number of iterations",(float) i);
   showcvec ("Roots",z,n,0);
   return 0;
}
/*---------------------------------------------------------------------*/

