/*------------------------------------------------------------------*/
/* Example 6.3.2: Bisection Search                                  */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float f (vector x,int n)
{
   return cos(PI*x[1])/(1 + x[1]*x[1]);
}

void g (vector x,int n,vector df)
{
   df[1] = (1 + x[1]*x[1])*(-PI)*sin(PI*x[1]) - 2*x[1]*cos(PI*x[1]);
   df[1] /= pow(1+x[1]*x[1],2);
}

int main (void)
{
   int		n = 1,
   		p = 200,
   		r = 0,
   		s = 0,
		i,err;
   float	a,b,c,eps,
                mu = 0,
		h = 1,
		dx = 4;	
   vector	x = vec(n,""),
		d = vec(n,"1"),
                t = vec (p,""),
                y = vec (p,""); 

/* Find a three-point pattern */

   printf ("\nExample 6.3.2: Bisection Search");
   i = bracket (h,x,d,mu,n,r,s,&a,&b,&c,&err,f,NULL,NULL);
   printf ("\n\nFunction evaluations = %i",i);
   printf ("\nThree-point pattern = (%.7f,%.7f,%.7f).",a,b,c);

/* Reduce interval of uncertainty */    

   eps = sqrt(epsilon());
   i = bisectd (x,d,a,c,eps,mu,n,r,s,&x[1],f,g,NULL,NULL);
   printf ("\nOptimal x = %.7f",x[1]);
   printf ("\nf(%g) = %.7f",x[1],f(x,n));
   printf ("\nFunction evaluations = %i",i);
   
/* Graph the function */

   for (i = 1; i <= p; i++)
   {
      t[i] = (i-1)*dx/(p-1);
      x[1] = t[i];
      y[i] = f(x,n);
   }
   graphxy (t,y,p,"Minimization of a Function with Local Extrema",
            "x","F(x)","fig633");
   wait();
   return 0;
 } 
/*------------------------------------------------------------------*/

   
   


