/*------------------------------------------------------------------*/
/* Example 6.5.1: Fletcher-Reeves Conjugate Gradient Method */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float f (vector x,int n)
{
   float y;
   y = pow(x[1]-x[2],4) + pow(x[1]*x[1]+x[2]-2,2) + pow(x[1]*x[2]-1,2);	
   return y;
}
   
void g (vector x,int n,vector df)
{
   df[1] = 4*pow(x[1]-x[2],3)  + 2*(x[1]*x[1]+x[2]-2)*2*x[1] +
           2*(x[1]*x[2]-1)*x[2];
   df[2] = -4*pow(x[1]-x[2],3) + 2*(x[1]*x[1]+x[2]-2) +
           2*(x[1]*x[2]-1)*x[1];
}

int main (void)
{
   int		n = 2,
   		m = 1000,
   		p = 50,
   		v = n,
		i,j,ev;
   float	eps = 1.e-5,
		d = 2;
   vector	x = vec(n,""),
                x1 = vec (p,""),
                x2 = vec (p,"");
   matrix	Y = mat (p,p,""); 

/* Find a minimum */

   printf ("\nExample 6.5.1: Conjugate-Gradient Method\n");
   printf ("\n\nIterations = %i",conjgrad(x,eps,n,m,v,&ev,f,g));
   printf ("\nFunction evaluations = %i.",ev);
   printf ("\nOptimal x    = [%.7f,%.7f]",x[1],x[2]);
   printf ("\nf(x)         = %.7f",f(x,n));

   printf ("\n\n Numerical Gradient:\n"); 
   zerovec (x,n);
   printf ("\nIterations = %i",conjgrad (x,eps,n,m,v,&ev,f,NULL));
   printf ("\nFunction evaluations = %i.",ev);
   printf ("\nOptimal x    = [%.7f,%.7f]",x[1],x[2]);
   printf ("\nf(x)         = %.7f",f(x,n)); 
   
/* Plot the objective function */

   for (i = 1; i <= p; i++)
   {
      x1[i] = (i-1)*d/(p-1);
      x2[i] = (i-1)*d/(p-1);
   }
   for (i = 1; i <= p; i++)
      for (j = 1; j <= p; j++)
      {
      	 x[1] = x1[i];
      	 x[2] = x2[j];
         Y[i][j] = f(x,n);
      }
   plotxyz (x1,x2,Y,p,p,"A Nonquadratic Objective Surface",
            "x_1","x_2","f(x)","fig651");
   wait();
   return 0;
} 
/*------------------------------------------------------------------*/

   

