/*------------------------------------------------------------------*/
/* Example 6.6.1: Davidon-Fletcher-Powell Method */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h" 

float	a = 3,			/* coordinates of minimum */
	b = 3;	
int	q = 8,			/* orders of objective terms */
	r = 4;
	
float f (vector x,int n)
{
   float 	y1,y2,y;
   y1 = pow (x[1]-a,q);
   y2 = pow (x[2]-b,r);
   y = y1/(1 + y1) + y2/(1 + y2); 
   return y;
}
   
void g (vector x,int n,vector df)
{
   float	y1,y2;
   y1 = pow(x[1]-a,q);
   y2 = pow(x[2]-b,r);
   df[1] = (1 + y1)*q*pow(x[1]-a,q-1) - y1*q*pow(x[1]-a,q-1);
   df[1] /= pow(1+y1,2);
   df[2] = (1 + y2)*r*pow(x[2]-b,r-1) - y2*r*pow(x[2]-b,r-1);
   df[2] /= pow(1+y2,2);
}

int main (void)
{
   int		n = 2,
   		m = 1000,
   		p = 100,
   		v = n,
		i,j,ev;
   float	eps = 2.e-7,
		d = 6;
   vector	x = vec(n,"0,0"),
                x1 = vec (p,""),
                x2 = vec (p,"");
   matrix	Y = mat (p,p,""); 

/* Find a minimum */

   printf ("\nExample 6.6.1: Davidon-Fletcher-Powell (DFP) Method\n");
   zerovec (x,n);
   printf ("\nIterations = %i",dfp (x,eps,n,m,v,&ev,f,g));
   printf ("\nFunction evaluations = %i.",ev);
   printf ("\nOptimal x    = [%.7f,%.7f]",x[1],x[2]);
   printf ("\nf(x)         = %.7f",f(x,n)); 

   printf ("\n\nNumerical Gradient:\n"); 
   zerovec (x,n);
   printf ("\nIterations = %i",dfp (x,eps,n,m,v,&ev,f,NULL));
   printf ("\nFunction evaluations = %i.",ev);
   printf ("\nOptimal x    = [%.7f,%.7f]",x[1],x[2]);
   printf ("\nf(x)         = %.7f",f(x,n)); 
   
/* Plot the objective function */

   for (i = 1; i <= p; i++)
   {
      x1[i] = (i-1)*d/(p-1);
      x2[i] = (i-1)*d/(p-1);
   }
   for (i = 1; i <= p; i++)
      for (j = 1; j <= p; j++)
      {
      	 x[1] = x1[i];
      	 x[2] = x2[j];
         Y[i][j] = f(x,n);
      }
   plotxyz (x1,x2,Y,p,p,
            "A Rational Polynomial Objective Surface",
            "x_1","x_2","f(x)","fig661");
   wait();
   return 0;
} 
/*------------------------------------------------------------------*/

   


