/*------------------------------------------------------------------*/
/* Example 6.8.1: Simulated Annealing */
/*------------------------------------------------------------------*/

#define DISPLAY_OPTIM  
#include "c:\nlib\util.h"

float	r1 = 3,			/* coordinates of minimum */
	r2 = 2;	
	
float f (vector x,int n)
{
   float	x1,x2,y;
   x1 = x[1] - r1;
   x2 = x[2] - r2;
   y = -cos(PI*x1)*cos(PI*x2)/(1 + x1*x1 + x2*x2);
   return y;
}
   
int main (void)
{
   int		n = 2,
		p = 100,
		m = 5000,
		i,j,ev;
   float	f0 = -1,
    		f1 = 1,
   		e1 = 0.1,
                e2 = 1.e-4,
                mu = 100,
		a0,b0,c;
   vector	x1 = vec (p,""),
                x2 = vec (p,""),
                x0 = vec (n,"0 0"),
                x  = vec (n,""),
                a = vec (n,""),
                b = vec (n,""); 
   matrix	F = mat (p,p,"");

/* Initialize */

   printf ("\nExample 6.8.1: Simulated Annealing\n");
   e1 = prompt ("Enter error tolerance",0,1,e1);
   c  = prompt ("Enter localization parameter",0,1,0.1); 
   a0 = prompt ("Enter lower limit of x",-1000,1000,0);
   b0 = prompt ("Enter upper limit of x",a0,1000,5);
   for (i = 1; i <= n; i++)
   {
      a[i] = a0;
      b[i] = b0;
   }   	
   
/* Find the minimum using Boltzmann distribution */

   copyvec (x0,n,x);
   j = anneal (x,f0,f1,e1,e2,c,mu,n,m,a,b,&ev,f);
   printf ("\n\nError tolerance = %.3f",e1);
   printf ("\nLocalization parameter = %.3f",c);
   printf ("\n[a,b] = [%f,%f]",a0,b0);
   printf ("\nTotal iterations = %i.",j);
   printf ("\nFunction evaluations = %i.",ev);
   printf ("\nOptimal x = [%.7f,%.7f]",x[1],x[2]); 
   printf ("\nOptimal f(x) = %.7f",f(x,n));
   
/* Plot objective function */

   for (i = 1; i <= p; i++)
   {
      x1[i] = (i-1)*2*r1/(p-1);
      for (j = 1; j <= p; j++)
      {
         x2[j] = (j-1)*2*r2/(p-1);
         x[1] = x1[i];
         x[2] = x2[j];
         F[i][j] = f(x,n);
      }
   }
   plotxyz (x1,x2,F,p,p,"The Objective Surface",
            "x_1","x_2","f(x)","fig683");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   
