/*------------------------------------------------------------------*/
/* Example 6.9.1: Heat Exchanger                                    */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

#define   M 16 	                        /* number of data points */
float     t[M+1],                       /* independent variables */  
          y[M+1];                       /* dependent variables */

float F (float t,vector q,int n)        /* data generation */
{
   float      a,
	      y = 0;
   a = -(t - q[3])/MAX(q[2],0.1f);
   if (t > q[3])
      y = (float) (q[1]*(1 - exp(a)));
   return y;
}   
      
float f (vector x,int n)               /* objective function */ 
{
   int 		i;
   float	z = 0;
   for (i = 1; i <= M; i++) 
      z += (float) pow(F(t[i],x,n)-y[i],2);
   return z/M;
}

int main (void)
{
   int          n = 3,                  /* number of variables */
                m = 250,                /* maximum iterations */
                p = 10*M,		/* number of plot points */
                i,			/* number of iterations */
	        ev,			/* number of function evaluations */
		j;  

   float        eps = 1.0e-5f,          /* error tolerance */
                T = 30.0f;              /* range of t (min) */

   vector       q = vec (n,"7.2,4.0,3.2"),  /* nominal parameters */
                x = vec (n,"3 3 3");	    /* initial guess */
                
   matrix	X = mat (2,p,""),
		Y = mat (2,p,"");

   FILE 	*d = fopen("e691.dat","w");		
		

/* Construct data */

   printf ("\nExample 6.9.1: Heat Exchanger\n");
   for (i = 1; i <= M; i++)
   {
      t[i] = (i-1)*T/(M-1);
      y[i] = F(t[i],q,n) + randu(-0.1f,0.1f);
   }
   for (i = 1; i <= M/2; i++)   
      fprintf (d,"\n %.0f & %.3f & %.0f & %.3f \\\\",
      t[i],y[i],t[M/2+i],y[M/2+i]); 
   
/* Curve fit parameters: conjugate-gradient */
      
   i = conjgrad (x,eps,n,m,n,&ev,f,NULL);
   shownum ("Iterations",(float) i);
   shownum ("Function evaluations",(float) ev);
   showvec ("x",x,n,0);
   shownum ("f(x)",f(x,n));
      
/* Display curves and data */

   for (i = 1; i <= p; i++)
   {
      j = MIN (i,M);	
      X[1][i] = (i-1)*T/(p-1);
      Y[1][i] = F(X[1][i],x,n); 
      X[2][i] = t[j];
      Y[2][i] = y[j];
   }
   graphmm (X,Y,2,p,"Heat Exchanger Step Response",
            "t (min)","y (deg)","fig692.m",1);
   wait();
   return 0;
}
/*------------------------------------------------------------------*/


