/*---------------------------------------------------------------------*/
/* Example 6.9.2: Transportation Planning                              */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float f (vector x,int n)
{
   float    c[7] = {0.0f,1.15f,2.43f,0.94f,
                    1.64f,1.97f,1.07f};       /* unit costs */
   return inner (c,x,n);
}	

void  p (vector x,int n,int r,vector y)
{

   float    a[3] = {0,2000,1200},             /* amount shipped */
            b[4] = {0,800,1400,1000};         /* amount received */

/* Shipping */

   y[1] = x[1] + x[2] + x[3] - a[1];
   y[2] = x[4] + x[5] + x[6] - a[2];
    
/* Receiving */

   y[3] = x[1] + x[4] - b[1];
   y[4] = x[2] + x[5] - b[2];
   y[5] = x[3] + x[6] - b[3];
}
	
void  q (vector x,int n,int s,vector y)
{
   copyvec (x,s,y);
}

int main (void)
{
   int          n = 6,                  /* number of variables */
                r = 5,                  /* equality constraints */
                s = n,                  /* inequality constraints */
                m = 100,                /* maximum iterations */ 
                eval,                   /* function evaluations */
                trials = 5,             /* number of runs */  
                i,j;                    /* iterations */
   float        eps = 1.0e-5f,          /* error tolerance */
                mu = 100.0f;            /* penalty parameter */
   vector       x = vec (n,""),         /* shipping schedule */
                y = vec (r,"");
   FILE         *g = fopen ("e692.dat","w");
		
/* Compute optimal solution for different penalty parameters */

   printf ("\nExample 6.9.2: Transportation Planning\n");
   for (j = 1; j <= trials; j++)
   {
      mu = (float) pow(10,j-2);
      zerovec (x,n);
      i = penalty (x,eps,mu,n,r,s,m,&eval,f,p,q);
      p(x,n,r,y);
      fprintf (g,"\n%10.1f & %10.2f & %10.4f \\\\",mu,f(x,n),vecnorm(y,r));
      fprintf (g,"\n & & \\\\"); 
      shownum ("Number of iterations",(float) i);
      shownum ("Number of scalar function evaluations",(float) eval);
      showvec ("Optimal x",x,n,0);
      shownum ("Optimal f(x)",f(x,n));
      shownum ("||p(x)||",vecnorm(y,r));
   }
   return 0;         
}
/*---------------------------------------------------------------------*/



