/*------------------------------------------------------------------*/
/* Example 6.9.3: Maximum Power Extraction                          */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"
#include "funr693.c"			/* nonlinear characteristic */ 		  	

float		R;		        /* load resistance (global) */

float p (float i)                       /* KVL constraint */
{
   float     y,Vs = 5;
   y = funr693(i) + R*i - Vs; 
   return y;
}

float f (vector x,int n)                /* objective function */ 
{
   int		m = 500;
		
   float	ep1 = 1.e-6f,
      	        x0 = 0,
		x1 = 10,
		i,y;

    R = x[1];				/* used by p(i) */
    bisect (x0,x1,ep1,m,&i,p);
    y = R*i*i;
    return -y;
}

int main (void)
{
   int          n = 1,                  /* number of variables */
                m = 500,                /* maximum iterations */
                q = 100,                /* plot points */ 
                i,			/* number of iterations */
                v = 1,			/* order of method */
		ev;			/* number of function evaluations */ 
                
   float        eps = 1.0e-6f,          /* error tolerance */
		y;			/* current */	
   
   vector	x  = vec (n,"2"),
                x1 = vec (q,""),
                y1 = vec (q,"");
                
/* Find optimal load resistance */

   printf ("\nExample 6.9.3: Maximum Power Extraction\n");
   i = dfp (x,eps,n,m,v,&ev,f,NULL);
   shownum ("Iterations",(float) i);
   shownum ("Function evaluations",(float) ev);
   shownum ("Load Resistance x (ohm)",x[1]);

/* Compute power dissipated */

   R = x[1];					/* used by p(i) */
   i = bisect (0,2*x[1],eps,m,&y,p);
   shownum ("Current I (A)",y);
   shownum ("Power Delivered P (watt)",-f(x,n));

/* Plot objective function */

   for (i = 1; i <= q; i++)
   {
       x[1] = (i-1)/10.0;
       x1[i] = x[1];	 
       y1[i] = f(x,n);
   }
   graphxy (x1,y1,q,"Objective Function for Example 6.9.3",
            "x","f(x)","fig696");      
   wait();
   return 0;
}
/*------------------------------------------------------------------*/

