/*---------------------------------------------------------------------*/
/* Example 6.9.4: Container Design                                     */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float     alpha = 80,                      /* area of sheet (cm^2) */
          beta  = 3.0;                     /* maximum height (cm) */

float f (vector x,int n)                   /* objective function */
{
   return -x[1]*x[2]*x[3];
}

void  p (vector x,int n,int r,vector y)    /* equality constraints */  
{
   y[1] = (x[1] + 2*x[3])*(x[2] + 2*x[3])
           - 4*x[3]*x[3] - alpha;
}

void  q (vector x,int n,int s,vector y)    /* inequality constraints */
{
   copyvec (x,s,y);
   y[4] = beta - x[3];
}

int main (void)
{
   int          n = 3,                  /* number of variables */
                r = 1,                  /* number of equality constraints */
                s = 4,                  /* number of inequality constraints */
                m = 250,                /* maximum iterations */
                i,                      /* number of iterations */
                ev;                     /* number of function evaluations */ 
   float        eps = 1.0e-5f,          /* error tolerance */
                mu = 40.0f;             /* penalty parameter */
   vector       x = vec(n,"2 2 2"),     /* initial guess */
                y = vec(r,""); 

/* Find optimal box size */

   printf ("\nExample 6.9.4: Container Design\n");
   mu = prompt ("Enter penalty parameter mu: ",0.01f,1000.0f,100.0f);
   i = penalty (x,eps,mu,n,r,s,m,&ev,f,p,q);

/* Display results */

   shownum ("Iterations",(float) i);
   shownum ("Function evaluations",(float) ev);
   showvec ("Container dimensions x",x,n,0);
   shownum ("Container volume",-f(x,n));
   p(x,n,r,y);
   shownum ("||p(x)||",vecnorm(y,r));
   return 0;
}
/*---------------------------------------------------------------------*/


