/*------------------------------------------------------------------*/
/* Example 7.3.2: Differentiation of Filtered Noisy Data */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

int		q = 256;
float		h = 1;
vector		z;

float	f1 (float z)
{
   float	T = 64;
   return exp(-z/T)*sin(2*PI*z/T);
}
	
float	f2 (float x)
{
   int	k = MAX(1,MIN(q,1 + x/h));
   return z[k];
}

float   g (float f)
{
   float fc = 0.5;
   return (f <= fc) ? 1 : 0;
}
         
int main (void)
{
   int		p = 3,
                e = 0,
                n = 2,
		m = -1,
		i;
   float	dn = 0.002,
		fc = 0.5; 
   vector       t = vec (q,""),
                y = vec (q,""),
                noise = vec (q,""),
                b = vec (2*p+1,""),
                v = vec (2*p+1,"");
   matrix       D = mat (2,q,"");

/* Initialize */

   printf ("\nExample 7.3.2: Differentiation of Filtered Noisy Data\n");
   randinit (0);
   z = vec (q,"");
   
/* Construct signals */
   
   for (i = 1; i <= q; i++)
   {
      t[i] = (i - 1)*h;	
      noise[i] = randg (0,dn);
      y[i] = f1(t[i]) + noise[i];
   }

/* Filter the signal */

   fir (g,p,b);
   showvec ("filter coefficients",b,2*p+1,0);
   for (i = 1; i <= q; i++)
      z[i] = arma (y[i],b,v,0,2*p);
   
/* Compute derivatives */

   for (i = 1; i <= q; i++)
   {
      D[1][i] = deriv  (i,h,n,m,e,f1);
      D[2][i] = deriv  (i,h,n,m,e,f2);
   }
   graphxm (t,D,2,q,"Derivative of Filtered Signal",
            "k","z''","fig733");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   


