/*---------------------------------------------------------------------*/
/* Example 7.9.1: Change in Enthalpy                                   */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float	g (float x)
{
   int          m = 11;
   float        y;
   matrix       D = mat (2,m,"50 60 70 80 90 100 110 120 130 140 150 "
                             ".1235 .1994 .3119 .4739 0.7014 1.014 "
                             "1.433 1.958 2.701 3.613 4.758");
   y = piece (x,D[1],D[2],m);
   freemat (D,2);
   return y;
}                           

int main (void)
{
   int          m = 11,              /* number of data points */
                c = 0;               /* central difference */
   float        f  = 1.e5f,          /* conversion factor */ 
                vg = 1.673f,         /* specific volume (gas) */
                vf = 0.00104f,       /* specific volume (liquid) */
                dT = 10.0f,          /* temperature spacing */
                T0 = 100.0f,         /* temperature point */ 		
                dh,                  /* change in enthalpy */
                s;                   /* slope dp/DT */	
   
/* Find numerical derivative, dp/dT, at T = 100 */

   printf ("\nExample 7.9.1: Change in Enthalpy\n");
   shownum ("3-point dp/dT",s = deriv (T0,dT,3,c,0,g));
   shownum ("5-point dp/dT",s = deriv (T0,dT,5,c,0,g));
   shownum ("3-point extrapolated dp/dT",s = deriv (T0,dT,3,c,1,g));
   shownum ("5-point extrapolated dp/dT",s = deriv (T0,dT,5,c,1,g));

/* Find change in enthalpy */

   dh = 373.15f*(vg - vf)*f*s;
   shownum ("Change in enthalpy (kJ/kg)",dh/1000);
   return 0; 
}
/*---------------------------------------------------------------------*/


