/* -------------------------------------------------------------- */
/* Example 7.9.2: Dam Design                                      */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

int	m,n;				/* number of data points */
vector	x,y;				/* (x,y) coordinates */
matrix	Z;				/* depth measurements */ 

float f (vector x0,int p)               /* volume integrand */
{
   return bilin (x0[1],x0[2],x,y,Z,m,n);
}

float g (float x0)                      /* force integrand */ 
{
   float	rho  = 1000, 		/* water density (kg/m^3) */
		g    = 9.81f,        	/* gravity (m/s^2) */
   		x[2] = {0,0}; 

   x[1] = x0;
   return (float) (rho*g*pow(f(x,2),2)/2);
}

int main (void)
{
   int          q = 80,			/* number of plot points */
		r = 5000,		/* number of random points */ 	
                i,j;

   float	V,			/* water volume (m^3) */
		F;			/* water force (N) */	              

   vector	a = vec (2,""),		/* limits on x (m) */
		b = vec (2,""),		/* limits on y (m) */
		x1 = vec (q,""),
		y1 = vec (q,""),
		x0 = vec (2,"");
   		
   matrix	Z1 = mat (q,q,"");

   FILE		*fp = fopen ("data792.m","r");		
   
/* Get depth data from data file */

   printf ("\nExample 7.9.2: Dam Design\n");
   x = getvec (fp,&m);
   y = getvec (fp,&n);
   Z = getmat (fp,&m,&n);

/* Plot surface using bilinear interpolation */
   
   for (i = 1; i <= q; i++)
   {
      x1[i] = x[1] + (x[m] - x[1])*(i-1)/(q - 1); 	
      for (j = 1; j <= q; j++)
      {
         y1[j] = y[1] + (y[n] - y[1])*(j-1)/(q - 1);
         x0[1] = x1[i];
         x0[2] = y1[j];  
         Z1[i][j] = f(x0,2);
      }
   }   
   plotxyz (x1,y1,Z1,q,q,"Pond Depth using Bilinear Interpolation",
            "x","y","z","fig791.m");
   
/* Compute volume of water in pond */

   a[1] = x[1];
   a[2] = y[1];
   b[1] = x[m];
   b[2] = y[n];
   V = -monte (a,b,2,r,f);
   shownum ("Volume of water (m^3))",V); 
   
/* Compute force on dam */

   F = simpson (x[1],x[m],100,g); 
   shownum ("Force on dam (kg/(m-s^2))",F);
   return 0; 
}
/* -------------------------------------------------------------- */


