/*---------------------------------------------------------------------*/
/* Example 7.9.3: RC Network                                           */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float f (float t)
{
   return (float) (t*exp(-t)/(1 + pow(cos(t),2))/100);
}

int main (void)
{
   int          q = 101,                /* number of plot points */
                n = 10,                 /* number of panels */
                i;
   float        T = 10.0f,              /* upper limit */
                R = 33.0f,              /* resistance (ohm) */
                C = 470.e-6f;           /* capacitance (F) */
   vector       t = vec (q,""),         /* time (sec) */
                x = vec (q,""),         /* capacitor voltage (V) */
                y = vec (q,""),         /* input port voltage (V) */
                u = vec (q,"");
		
/* Compute capacitor and port voltage */

   printf ("\nExample 7.9.3: RC Network\n");
   x[1] = 2.0;
   for (i = 1; i <= q; i++)
   {
      t[i] = (i-1)*T/(q - 1);
      u[i] = 1000*f(t[i]);
      if (i > 1)
         x[i] = x[i-1] + (1/C)*trapint(t[i-1],t[i],n,f);
      y[i] = R*f(t[i]) + x[i];
   }
   
/* Plot results */

   graphxy (t,y,q,"Voltage at Input Port",
            "t (sec)","y (V)","fig793");
   shownum ("Final voltage (V)",y[q]);
   return 0;
}      
/*---------------------------------------------------------------------*/


