/* -------------------------------------------------------------- */
/* Example 7.9.4: Link of Robotic Arm                             */
/* -------------------------------------------------------------- */

#include "c:\nlib\util.h"

float        L   = 0.9f,             /* length */		
             r1  = 0.1f,             /* outer radius */
             r2  = 0.02f;            /* inner radius */

float f (vector x,int m)
{
/* Link of robotic arm */

   float        rho = 100.0f,           /* density */
                w   = 0.1f,             /* thickness */
                z,y;

   z = (float) sqrt(inner(x,x,2));
   y = x[1] - (L - 2*r1);             
   if (((x[1] < 0) && (z > r1)) ||
       ((y > 0) && (y*y + x[2]*x[2] > r1*r1)) ||
       (z < r2))
      return 0; 
   else  
      return rho*w*z*z;
}

int main (void)
{
   int		n = 2,			/* dimension of integral */
		p = 10,			/* number of runs */
		r = 10000,		/* number of random points */
                i;

   float	J = 0,			/* moment of inertia */
		y;
   
   vector	a = vec (n,""),		/* limits on x (m) */
		b = vec (n,"");		/* limits on y (m) */
   
/* Initialize */

   printf ("\nExample 7.9.4: Link of Robotic Arm\n");
   a[1] = -r1;
   b[1] = L - r1;
   a[2] = -r1;
   b[2] = r1;
   randinit (1000);

/* Compute moment of inertia of link use average of p runs */ 

   for (i = 1; i <= p; i++)
   {
       y = monte (a,b,n,r,f);
       printf ("\nRun %i of %i = %g",i,p,y);
       J += y;
   }    
   J /= p;
   shownum ("Moment of inertia J (kg-m^2)",J);
   return 0;
}
/*------------------------------------------------------------------*/
