/*------------------------------------------------------------------*/
/* Example 8.3.1: Runge-Kutta Methods */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float y (float t)
{
return (1 - (10.0/9.0)*exp(-t) + (1.0/9.0)*exp(-10*t));
}

void f (float t,vector x,int n,vector dx)
{
/* Description: Satellite attitude control */

   dx[1] = x[2];
   dx[2] = 10 - 10*x[1] - 11*x[2];
} 

int main (void)
{
   int		n = 2,
		p = 6,
		r = 3,
		m0 = 5*pow(2,p-1)+1,
                m,i,j,k;

   float	alpha = 0,
		beta = 1,
		t;

   vector	x = vec (n,""),
                z = vec (n,""),
                h = vec (p,"");

   matrix	Q = mat (r,n,""),
                Y = mat (r+1,m0,""),
                E = mat (r,p,"");

   printf ("\nExample 8.3.1: Runge-Kutta Methods\n");
   for (j = 1; j <= p; j++)
   {
      m = 5*pow(2,j-1) + 1;
      h[j] = (beta - alpha)/(m - 1);
      
/* First-order RK method (Euler) */

      zerovec (x,n);
      for (k = 1; k <= m; k++)
      {
         t = alpha + (k-1)*h[j];
         f(t,x,n,Q[1]);
         for (i = 1; i <= n; i++)
            x[i] += h[j]*Q[1][i];
         Y[1][k] = x[1];   
         E[1][j] = MAX(E[1][j],fabs(y(t)-x[1]));   
      }

/* Second-order RK method */

      zerovec (x,n);
      for (k = 1; k <= m; k++)
      {
         t = alpha + (k-1)*h[j];
         f(t,x,n,Q[1]);
         for (i = 1; i <= n; i++)
            z[i] = x[i] + h[j]*Q[1][i];
         f(t+h[j],z,n,Q[2]);
         for (i = 1; i <= n; i++)
            x[i] += (h[j]/2)*(Q[1][i] + Q[2][i]);
         Y[2][k] = x[1];   
         E[2][j] = MAX(E[2][j],fabs(y(t)-x[1]));   
      }

/* Third-order RK method */

      zerovec (x,n);
      for (k = 1; k <= m; k++)
      {
         t = alpha + (k-1)*h[j];
         f(t,x,n,Q[1]);
         for (i = 1; i <= n; i++)
            z[i] = x[i] + (h[j]/2)*Q[1][i];
         f(t+h[j]/2,z,n,Q[2]);
         for (i = 1; i <= n; i++)
            z[i] = x[i] - h[j]*Q[1][i] + 2*h[j]*Q[2][i];
         f(t+h[j],z,n,Q[3]);  
         for (i = 1; i <= n; i++)
            x[i] += (h[j]/6)*(Q[1][i] + 4*Q[2][i] + Q[3][i]);
         Y[3][k] = x[1];
         E[3][j] = MAX(E[3][j],fabs(y(t)-x[1]));   
         Y[4][k] = y(t);    
      }
   }

/* Display results */

   showvec ("step sizes",h,p,0); 
   graphmat (Y,4,m,"","k","y","temp");
   for (j = 1; j <= p; j++)
   {
      printf ("%.5f ",h[j]);
      for (i = 1; i <= r; i++)
         printf ("& %12.7f ",E[i][j]);
      printf (" \\\\ \n");
   }   
   graphxm (h,E,r,p,"Comparison of Runge-Kutta Methods",
            "h","E","fig831");
   addlabel(.15,.21,"1","fig831");
   addlabel(.15,.16,"2","fig831");
   addlabel(.15,.105,"3","fig831");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/

