/*------------------------------------------------------------------*/
/* Example 8.3.2: Fourth-Order Runge-Kutta Method                   */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

void f (float t,vector x,int n,vector dx)
{
/* Description: Predator-prey equations */

   float 	b1=1,b2=1,c1=1,c2=1;
   dx[1] = ( b1 - c1*x[2])*x[1];
   dx[2] = (-b2 + c2*x[1])*x[2];
} 

int main (void)
{
   int		n = 2,
		m = 251,
		k,j;
   float	alpha = 0,
		beta = 10,
		e = 0,
		h = (beta - alpha)/(m - 1), 
		e0,t;
   vector	x0 = vec (n,"0.5,0.5"),
   		x1 = vec (n,"");
   matrix	X = mat (n,m,"");

/* Initialize */

   printf ("\nExample 8.3.2: Fourth-Order Runge-Kutta Method\n");
   putcol (X,n,m,1,x0);
   
/* Solve the system */
   
   for (k = 1; k < m; k++)
   {
     t = (k - 1)*h;
     e0 = rkfstep (x0,t,t+h,n,x1,f);
     copyvec (x1,n,x0);
     putcol (X,n,m,k+1,x1);
     e = MAX (e,e0);
   }
     
/* Display results */

   shownum ("maximum local error",e);
   showmat ("X",X,n,m,1);
   graphxy (X[1],X[2],m,"Predator-Prey Population Levels",
            "x_1 (prey)","x_2 (predator)","fig832");
   wait();
   return 0;
 }
/*------------------------------------------------------------------*/
   



