/*------------------------------------------------------------------*/
/* Example 8.4.1: Runge-Kutta-Fehhberg Method */
/*------------------------------------------------------------------*/

#define DISPLAY_ODE
#include "c:\nlib\util.h"

void f (float t,vector x,int n,vector dx)
{
/* Description: Predator-prey equations */

   float 	b1=1,b2=1,c1=1,c2=1;
   dx[1] = ( b1 - c1*x[2])*x[1];
   dx[2] = (-b2 + c2*x[1])*x[2];
} 

int main (void)
{
   long		q = 5000,
		r;
   int		n = 2,
                p = 3,
		m = 100,
		k,j;
   float	alpha = 0,
   		beta = 16,
                h = (beta - alpha)/(m - 1),
		eps,e;
   vector	x0 = vec (n,"0.5,0.5"),
                t  = vec (m,""),
                x  = vec (n,"");
   matrix	Y = mat (p,m-1,"");

/* Solve the system using different error bounds */

   printf ("\nExample 8.4.1: Runge-Kutta-Fehlberg Method\n");
   for (j = 1; j <= p; j++)
   {
      eps = pow(10,-(3+j));
      copyvec (x0,n,x);
      for (k = 1; k < m; k++)
      {
         t[k] = (k - 1)*h;
         r = rkf0 (x,t[k],t[k]+h,n,eps,q,&e,f);
         if (r > q)
            shownum ("Function evaluations",r);
         Y[j][k] = stepsize;
      }
   }
        
/* Display results */

   showmat ("Step sizes",Y,p,m-1,1);
   graphxm (t,Y,p,m-1,
            "Adaptive Step Size Control with Different Error Bounds",
            "t","h","fig841");
   addlabel (8,.74,"10^-^4","fig841");
   addlabel (8,.48,"10^-^5","fig841");
   addlabel (8,.16,"10^-^6","fig841");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   

