/*------------------------------------------------------------------*/
/* Example 8.6.1: Extrapolation Method                              */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

void f (float t,vector x,int n,vector dx)
{
/* Desription: A three-dimensional linear system. */

   dx[1] = x[2];
   dx[2] = x[3];
   dx[3] = -2*x[1] - 5*x[2] - 4*x[3];
}

int main (void)
{
   long		q = 5000;
   int		n     	= 3,
		m     	= 9,
		k,j;
   float	alpha	= 0,	
   		beta  	= 4.0,
		h	= (beta-alpha)/(m-1),
		eps 	= 1.e-7;
   vector	x0    	= vec (n,"1,-3,6"),
		p	= vec (m-1,""),
   		t	= vec (m,""),
   		e 	= vec (m-1,"");
   matrix	X	= mat (n,m,""),
		E	= mat (m-1,n,"");

/* Exact solution */

   printf ("\nExample 8.6.1: Extrapolation Method\n");
   for (k = 1; k <= m; k++)
   {
      t[k] = (k - 1)*h;
      X[1][k] =    -t[k]*exp(-t[k]) +   exp(-2*t[k]);
      X[2][k] = (t[k]-1)*exp(-t[k]) - 2*exp(-2*t[k]);
      X[3][k] = (2-t[k])*exp(-t[k]) + 4*exp(-2*t[k]);
   }
   graphxm (t,X,n,m,"Three-Dimensional Linear System",
            "t","x","fig861");  
   addlabel (0.6,.30,"x_1","fig861");
   addlabel (0.6,-1.20,"x_2","fig861");
   addlabel (0.6,2.40,"x_3","fig861");
 
/* Extrapolation method */
   
   for (k = 1; k < m; k++)
   {
      p[k] = bsext0 (x0,t[k],t[k+1],n,eps,q,&e[k],f);
      for (j = 1; j <= n; j++)
         E[k][j] = x0[j] - X[j][k+1];
   }
         
   for (k = 1; k < m; k++)
      printf ("\n %.1f & %.0f & %12.7e & %12.7e \\\\",
               t[k+1],p[k],e[k],vecnorm(E[k],n));
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   
   
