/*------------------------------------------------------------------*/
/* Example 8.7.2: Stiff Differential Equations                      */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

void f (float t,vector x,int n,vector dxdt)
{
/* Desription: A Stiff Circuit  */

   dxdt[1] = -x[1] - x[2];
   dxdt[2] = -x[1] - 10001*x[2];
}

void fx (float t,vector x,int n,matrix dfdx)
{
/* Desription: Jacobian matrix: df(t,x)/dx */

   dfdx[1][1] = -1;
   dfdx[1][2] = -1;
   dfdx[2][1] = -1;
   dfdx[2][2] = -10001;
}

void ft (float t,vector x,int n,vector dfdt)
{
/* Desription: Time derivative: df(t,x)/dt */

   dfdt[1] = 0;
   dfdt[2] = 0;
}

int main (void)
{
   long		q       = 5000;
   int		n     	= 2,
		m     	= 11,
		k,j;
   float	alpha	= 0,	
   		beta  	= 1.0,
		h	= (beta-alpha)/(m-1),
		eps 	= 1.e-6;
   vector	t	= vec (m,"");
   matrix	X0	= mat (3,n,"1,-1 1,-1 1,-1"),
		E	= mat (m,3,""),
   		P	= mat (m,3,"");

/* Initialize */

   printf ("\nExample 8.7.2: Stiff Differential Equations\n");
   for (k = 1; k <= m; k++) 
      t[k] = alpha + (k-1)*h;
      
/* Solve stiff system */
   
   for (k = 1; k < m; k++)
   {
      P[k][1] = stiff0 (X0[1],t[k],t[k+1],n,eps,q,&E[k][1],f,fx,ft);
      P[k][2] = stiff0 (X0[2],t[k],t[k+1],n,eps,q,&E[k][2],f,NULL,NULL);
      P[k][3] = rkf0 (X0[3],t[k],t[k+1],n,eps,q,&E[k][3],f);
   }

/* Compute average values */      

   for (j = 1; j <= 3; j++)
   {
      for (k = 1; k < m; k++)
      {
         E[m][j] += E[k][j];
         P[m][j] += P[k][j];
      }
      E[m][j] /= m-1;
      P[m][j] /= m-1;
   }    

/* Display results */
   
/*
   showmat ("Truncation errors",E,m,3,0);
   showmat ("Function evaluations",P,m,3,0);
*/

   for (k = 1; k < m; k++)
      printf ("\n %.1f & %12.7e & %.0f & %12.7e & %.0f & %12.7e & %.0f \\\\",
               t[k+1],E[k][1],P[k][1],E[k][2],P[k][2],E[k][3],P[k][3]); 
   printf ("\n average & %12.7e & %.1f & %12.7e & %.1f & %12.7e & %.1f \\\\",
            E[m][1],P[m][1],E[m][2],P[m][2],E[m][3],P[m][3]);
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   
   
   

