/*------------------------------------------------------------------*/
/* Example 8.9.1: Chemical Reactor                                  */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

void tank (float t,vector x,int n,vector dx) 
{
/* Description: Stirred tank reactor. */

   float        q = 10.0f,	/* flow rate (m^3/min) */
		V = 2.0f,	/* mixture volume (m^3) */
		alpha = 2.6f,	/* reaction rate (moles/min) */
		u1 = 3.2f,	/* feed concentration 1 (moles/m^3) */
		u2 = 4.8f,	/* feed concentration 2 (moles/m^3) */
		b = q/V;
		
   dx[1] = b*(u1 - x[1]) - alpha*x[1]*x[2];
   dx[2] = b*(u2 - x[2]) - alpha*x[1]*x[2];
   dx[3] = -b*x[3] + alpha*x[1]*x[2];
}

int main (void)
{
   int          n       = 3,                    /* system dimension */
                m       = 100,                  /* solution points */
                r;				/* function evaluations */
                
   long		q = 5000;			/* maximum evaluations */

   float        alpha   = 0.0f,                 /* initial time */
                beta    = 1.2f,	                /* final time */
                eps     = 1.e-6f,               /* error bound */
                E;                              /* estimated error */
                
   vector       t       = vec (m,""),           /* solution times */
                x0      = vec (n,"5 3 0");      /* initial state */
                
   matrix       X       = mat (n,m,"");         /* solution points */
   
   printf ("\nExample 8.9.1: Chemical Reactor\n");
   r = rkf (x0,alpha,beta,n,m,eps,q,t,X,&E,tank);
   shownum ("Number of scalar function evaluations",(float) r);   
   shownum ("Maximum truncation error",E);
   shownum ("Final product concentration (moles/m^3)",X[n][m]);
   graphxm (t,X,n,m,
            "Chemical Concentrations in Stirred Tank Reactor",
            "t (min)","x(t) (moles/m^3)","fig892");
   addlabel (t[m]+.02,X[1][m]-.03,"x_1","fig892");
   addlabel (t[m]+.02,X[2][m]-.03,"x_2","fig892");
   addlabel (t[m]+.02,X[3][m]-.03,"x_3","fig892");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   

   
