/*---------------------------------------------------------------------*/
/* Example 8.9.2: Cantilever Beam                                      */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float           L = 2.0;        /* length of thin beam */

void beam (float z,vector x,int n,vector dx) 
{
/* Description: Cantilever Beam */

   float        rho = 10.0f,    /* linear mass density (kg/m) */
                g = 9.81f,      /* acceleration due to gravity (m/s^2) */
                EJ = 2400.0f;   /* moment of inertia * Young's modulus */

   dx[1] = x[2];
   dx[2] = (float) (-(g*rho/EJ)*pow(1+x[2]*x[2],1./3.)*(z*(z-L/2) 
           + L*L/2));
}   

int main (void)
{
   int          n       = 2,                    /* system dimension */
                m       = 100,                  /* solution points */
                r;                              /* function evaluations */
   long         q = 10000;                      /* maximum evaluations */
   float        alpha   = 0.0f,                 /* initial distance */
                beta    = L,                    /* final distance */
                eps     = 1.e-6f,               /* error bound */
                E;                              /* estimated error */
   vector       z       = vec (m,""),           /* solution points */
                x0      = vec (n,"");           /* initial state */
   matrix       X       = mat (n,m,"");         /* solution points */
   
/* Solve equations */ 
   
   printf ("\nExample 8.9.2: Cantilever Beam\n");
   r = bsext (x0,alpha,beta,n,m,eps,q,z,X,&E,beam);
   shownum ("Number of scalar function evaluations",(float) r);   
   shownum ("Maximum truncation error",E);
   shownum ("Maximum deflection (cm)",-100*X[1][m]);
   graphxy (z,X[1],m,"Deflection of Cantilever Beam",
            "z (m)","y (m)","fig894");
   wait();
   return 0;   
}
/*---------------------------------------------------------------------*/

   

   
