/*------------------------------------------------------------------*/
/* Example 8.9.3: Phase-Locked Loop                                 */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float		wc = 2*PI*1000,		/* center frequency (rad/s) */
		alpha = 1600,
		w0 = 2*PI*1050;

float u (float t)
{
/* Periodic input */

   float	a = 0.5f;   		/* input amplitude (V) */
   return (float) (a*sin(w0*t));
}   

void PLL (float t,vector x,int n,vector dx) 
{
/* Description: Stirred tank reactor. */

   float	tau = 3*PI/wc;	/* time constant */

   dx[1] = (float) ((alpha*u(t)*cos(x[2]) - x[1])/tau);
   dx[2] = x[1] + wc;
}   

int main (void)
{
   int          n       = 2,                    /* system dimension */
                m       = 1000,                 /* solution points */
                r,				/* function evaluations */
                i;
                
   long		q = 20000;			/* maximum evaluations */

   float        t1    = 0.025f,	                /* final time */
                eps   = 1.e-6f,                 /* error bound */
                E;                              /* estimated error */
                
   vector       t       = vec (m,""),           /* solution points */
   		u0	= vec (m,""),		/* input samples  */
   		y	= vec (m,""),		/* output samples */
   		v	= vec (m,""),		/* feedback signal */
                x0      = vec (n,"");	      	/* initial state */
                
   matrix       X       = mat (n,m,"");         /* solution points */
   
/* Solve equations */

   printf ("\nExample 8.9.3: Phase-Locked Loop\n");
   r = rkf (x0,0,t1,n,m,eps,q,t,X,&E,PLL);

/* Compute input and output */
   
   for (i = 1; i <= m; i++)
   {
      t[i] *= 1000;			/* to msec */ 
      u0[i] = u(t[i]/1000);
      y[i] = (X[1][i] + wc)/(2*PI);
      v[i] = (float) cos(X[2][i]);
   }

/* Display results */   
   
   shownum ("Number of scalar function evaluations",(float) r);   
   shownum ("Maximum truncation error",E);
   shownum ("Final estimate of frequency (Hz)",y[m]);
   graphxy (u0,v,m,"Oscillator Output vs Phase-Locked Loop Input",
            "u","v","fig896");
   graphxy (t,y,m,"Phase-Locked Loop Output",
            "t (msec)","y (Hz)","fig897");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   

   
