/*---------------------------------------------------------------------*/
/* Example 8.9.4: Turbulent Flow and Chaos                             */
/*---------------------------------------------------------------------*/

#include "c:\nlib\util.h"

void Lorenz (float t,vector x,int n,vector dx)
{
/* Description: The Lorenz attractor, a chaotic system. */

   float        sigma  = 10.0f,
                lambda = 24.0f,
                gamma  = 2.0f;
                
   dx[1] = sigma*(x[2] - x[1]);
   dx[2] = (1 + lambda - x[3])*x[1] - x[2];
   dx[3] = x[1]*x[2] - gamma*x[3];
}

int main (void)
{
   int          n   = 3,                    /* system dimension */
                m   = 4000;                 /* solution points */
   long         q   = 80000,                /* maximum evaluations */
                r;                          /* function evaluations */
   float        t0  = 0.0f,                 /* initial time */
                t1  = 30.0f,                /* final time */
                eps = 1.e-6f,               /* error bound */
                E;                          /* estimated error */
   vector       t   = vec (m,""),           /* solution times */
                x0  = vec (n,"1 0 20");     /* initial state */
   matrix       X   = mat (n,m,"");         /* solution points */

/* Solve equations */
   
   printf ("\nExample 8.9.4: Turbulent Flow and Chaos\n");
   r = rkf (x0,t0,t1,n,m,eps,q,t,X,&E,Lorenz);
   shownum ("Number of scalar function evaluations",(float) r);   
   shownum ("Maximum truncation error",E);
   graphxy (X[1],X[3],m,"The Lorenz Attractor: A Chaotic System",
            "x_1","x_3","fig898");
   wait();
   return 0;
}
/*---------------------------------------------------------------------*/


   

   
