/*------------------------------------------------------------------*/
/* Example 9.2.2: Steady State Temperature */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float g (float x,float y)
{
   return (exp(y)*cos(x) - exp(x)*cos(y));
}

int main (void)
{
   int          m = 39,                 /* x precision */		
 	        n = 39,                 /* y precision */
 	        q = 500,                /* maximum iterations */
 	        i,j;
   float        a = 4,                  /* maximum x */
                b = 4,                  /* maximim y */ 
                eps = 1.e-4,		/* error bound */ 
                alpha,du;
   vector	x = vec (m,""),		
   		y = vec (n,"");
   matrix       U = mat (m,n,"");       /* solution */

/* Initialize */

   printf ("\nExample 9.2.2: Steady-State Temperature\n");
   printf ("Computing solution ... ");
   i = poisson (a,b,m,n,q,eps,&alpha,x,y,U,NULL,g);
   shownum ("Number of iterations",i);
   shownum ("Optimal relaxation parameter",alpha);
   du = 0;
   for (i = 1; i <= m; i++)
      for (j = 1; j <= n; j++)
         du = MAX(du,fabs(U[i][j] - g(x[i],y[j])));
   shownum ("maximum error",du);
   plotxyz (x,y,U,m,n,"Steady-State Temperature Distribution",
            "x (m)","y (m)","u (^oC)","fig925");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/
   




