/*------------------------------------------------------------------*/
/* Example 9.5.3: Vibrating String                                  */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float	a = 2,                  /* string length */
        c1 = 0.1,		/* initial condition coefficients */
	c2 = 0.1;

float f (float x)
{
   return c1*sin(PI*x);
}

float g (float x)
{
   return 2*PI*c2*sin(PI*x);
}

float v (float t,float x)
{
   return sin(PI*x)*(c1*cos(2*PI*t) + c2*sin(2*PI*t));
}

int main (void)
{
   int          m = 80,                 /* t precision */		
 	        n = 39,                 /* x precision */
 	        i,j;
   float	T = 1.0,		/* maximum t */ 
                beta = 4.0,             /* gain */
                E = 0,			/* error */	
                dt,dx,gamma;	 
   vector	t = vec (m+1,""),	/* time grid values */
   		x = vec (n,"");		/* space grid values */
   matrix       u = mat (m+1,n,""),     /* solution */
 		w = mat (m+1,n,"");

/* Initialize */

   printf ("\nExample 9.5.3: Vibrating String\n");
   dt = T/m;
   dx = a/(n+1);
   gamma = beta*dt*dt/(dx*dx);
   shownum ("gamma",gamma);

/* Solve wave equation */      

   wave1 (T,a,m,n,beta,t,x,u,f,g);
   plotxyz (t,x,u,m+1,n,"Vibration of a String",
            "t (sec)","x (m)","u (m)","fig951");

/* Check the accuracy */

   for (i = 1; i <= m+1; i++)
      for (j = 1; j <= n; j++)
      {
      	 w[i][j] = v(t[i],x[j]);
         E = MAX(E,fabs(u[i][j]-w[i][j]));
      }
   shownum ("maximum error",E);
   return 0;
}
/*------------------------------------------------------------------*/
   


