/*------------------------------------------------------------------*/
/* Example 9.7.2: Plate Deflection                                  */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

int		m = 20,			/* number of x grid points */
		n = 20;			/* number or y grid points */
		
float		alpha;			/* relaxation parameter */ 

vector		xg,			/* x axis grid points */
		yg;			/* y axis grid points */	

matrix		U,			/* plate deflection (m) */ 
		V;			/* intermediate solution */


float f1 (float x,float y)
{
   float 	f = 2.e3f,		/* area load (N/m^2) */
                beta = 1.5e4;           /* flexural rigidity (m/N) */
   return f/beta;
}             

float f2 (float x,float y)
{
   return bilin (x,y,xg,yg,V,m,n);
}             

int main (void)
{
  int           q = 500,		/* maximum number of iterations */	
                r, 			/* number of iterations */
                i,j;
                
  float         a = 3.0f,               /* plate width (m) */
                b = 3.0f,               /* plate length (m) */ 
		eps = 1.e-5f;		/* error tolerance */

/* Initialize */

   printf ("\nExample 9.7.2: Plate Deflection\n"); 
   xg = vec (m,"");
   yg = vec (n,"");
   U = mat (m,n,"");
   V = mat (m,n,"");

/* Solve first Poisson system */

   r = poisson (a,b,m,n,q,eps,&alpha,xg,yg,V,f1,NULL);
   shownum ("Number of iterations",(float) r);
   shownum ("Relaxation parameter alpha",alpha);

/* Solve second Poisson system */

   r = poisson (a,b,m,n,q,eps,&alpha,xg,yg,U,f2,NULL);
   shownum ("Number of iterations",(float) r);
   shownum ("Maximum deflection (m)",maxmat(U,m,n,&i,&j));
   plotxyz (xg,yg,U,m,n,"Deflection of a Plate under Area Load",
            "x (m)","y (m)","u (m)","fig972");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/

