/*------------------------------------------------------------------*/
/* Example 9.7.3: Electrostatic Field                               */
/*------------------------------------------------------------------*/

#include "c:\nlib\util.h"

float           a = 1.0f,               /* width (m) */
                b = 1.0f;               /* length (m) */ 
		
float f (float x,float y)
{
   float        ep = 8.9e-12f,          /* permitivity of air (coul^2/N-m^2) */
                rho = 1.e-8f,           /* charge */
                z = 0.03f;
                
   if      ((fabs(x-0.4*a) < z) && (fabs(y - 0.4*b) < z))
      return -rho/ep;
   else if ((fabs(x-0.6*a) < z) && (fabs(y - 0.6*b) < z))
      return rho/ep;
   else
      return 0;
}             

int main (void)
{
   int          m = 30,                 /* number of x grid points */
                n = 30,                 /* number or y grid points */
                q = 500,                /* maximum number of iterations */	
                r,                      /* number of iterations */
                i;
   float        eps = 1.e-5f,           /* error tolerance */
                alpha;                  /* relaxation parameter */
   vector       x = vec (m,""),         /* x axis grid points (m) */
                y = vec (n,"");         /* y axis grid points (m) */	
   matrix       U = mat (m,n,"");       /* electrostatic potential (V) */
    
/* Solve Poisson equation */

   printf ("\nExample 9.7.3: Electrostatic Field\n"); 
   plotfun (0,a,0,b,"Charge Density","x","y","f(x,y)",f,"figf");
   r = poisson (a,b,m,n,q,eps,&alpha,x,y,U,f,NULL);
   shownum ("Relaxation parameter alpha",alpha);
   shownum ("Number of iterations",(float) r);
   plotxyz (x,y,U,m,n,"Electrostatic Potential due to Dipole",
            "x (cm)","y (cm)","u (V)","fig973");
   wait();
   return 0;
}
/*------------------------------------------------------------------*/

