%-----------------------------------------------------------------------
% Example 10.9.1: Heat Exchanger Frequency Response 
%-----------------------------------------------------------------------

% Initialize

   clc                      % clear screen
   clear                    % clear variables
   n   = 256;               % number of samples 
   T   = 0.25;              % sampling interval (min) 
   fs  = 1/T;               % sampling rate (samples/min) 
   a   = 10;                % gain (deg C-m^3/min) 
   tau = 4.5;               % time constant (min) 
   Td  = 1.5;               % time delay (min)    		
   u   = zeros (n,1);       % unit pulse input 
   y   = zeros (n,1);       % pulse response 
   t   = zeros (n,1);       % discrete times 	 

% Compute pulse response of heat exchanger 

   fprintf ('Example 10.9.1: Heat Exchanger Frequency Response\n');
   u(1) = 1;
   m  = round (Td/T);
   for k = 1 : n
      t(k) = (k-1)*T;
      if k > max(m+1,1)
         y(k) = y(k-1) + (T/tau)*(a*u(k-1-m) - y(k-1));
      end
   end

% Compute and display frequency response 

   [A,phi,f] = freqrsp (u,y,fs);
   graphxy(f(1:n/2),A(1:n/2),'Magnitude Response','f (samples/min)','A')  
%-----------------------------------------------------------------------
