function [u,v] = expfit (D,n)
%----------------------------------------------------------------
% Usage:       [u,v] = expfit (D,n)
%
% Description: Find the least-squares exponential fit function
%              for the data set D:
%
%              f(x) = u*exp(-v*x)
%
% Inputs:      D = 2 by n matrix with the independent variables
%                  in row 1 and the dependent variables in 
%                  row 2.  
%              n = number of data points (n >= 2)
%
% Outputs:     u = amplitude of exponential function
%              v = exponent of exponential function
%----------------------------------------------------------------

% Initialize

   n   = args (n,2,n,2,'expfit');  

% Form equations

   x = D(1,:);
   y = log(D(2,:));
   C = [n sum(x) ; sum(x) dot(x,x)];
   b = [sum(y) ; dot(x,y)];

% Find u and v

   a = C\b;
   u = exp(a(1));
   v = -a(2);
%----------------------------------------------------------------
