%----------------------------------------------------------------------
% Usage:       nlib 
%
% Description: Display the contents of the nlib toolbox.  The 
%              functions labeled (built-in) are available as
%              part of Matlab.
%
% Appendix 1:  Main program support functions
%
%   browse   => NLIB example browser
%   show     => display matrix on console screen
%   prompt   => prompt for a number in a specified range
%   wait     => display a message and pause 
%   graphmat => graph columns of a matrix as a family of curves
%   graphfun => graph a function of one variable 
%   graphxy  => graph matrix Y vs matrix X
%   plotmat  => plot a matrix Z as a surface
%   plotfun  => plot a function of two variables
%   plotxyz  => plot a matrix Z vs x and y  
%   randinit => initialize random number generator 
%   randu    => uniformly distributed random matrix A
%   randg    => Gaussian random matrix A
%   norm     => Holder norm of vector x (built-in)
%   args     => check user calling arguments
%   putmat   => write matrix to file
%   nlibpath => append NLIB to the Matlab path
%   chkvec   => check to see if a matrix is a column vector
%   chkfun   => check to see if a function returns a column vector
%   list     => display matrix on screen
%   startup  => Matlab startup file 
%       
% Chapter  2:  Linear Algebraic Systems
%
%   rank     => rank of matrix (built-in)
%   gauss    => solve Ax = b by Gaussian elimination
%   lufac    => LU factorization of a matrix A 
%   lusub    => LU substitution
%   ludec    => LU decomposition of Ax = b
%   det      => determinant matrix (built-in)
%   inv      => inverse matrix (built-in)  
%   condnum  => condition number of matrix 
%   residual => norm of residual error vector
%   trifac   => LU factorization of a tridiagonal matrix 
%   trisub   => tridiagonal substitution
%   tridec   => decomposition of tridiagonal Ax = b
%   sr       => successive relaxation iterative method
%
% Chapter  3:  Eigenvalues and Eigenvectors
%
%   poly     => characteristic polynomial of matrix (built-in)
%   house    => Householder transformation to upper Hessenberg form
%   jacobi   => Jacobi method for symmetric matrices 
%   qr       => orthogonal-triangular factorization (built-in)
%   eig      => eigenvalues and eigenvectors (built-in)
%   powereig => dominant eigenvalue and eigenvector 
%   svd      => singular value decomposition (built-in)
%   trace    => trace of matrix A (built-in)
%
% Chapter  4:  Curve Fitting
%
%   interp1  => piecewise-linear interpolation (built-in)
%   spline   => cubic spline interpolation (built-in)
%   polyfit  => least-squares fit of a polynomial (built-in)
%   polyval  => polynomial evaluation with Horner's method (built-in)
%   polynom  => polynomial evaluation using reversed coefficients  
%   bilin    => two-dimensional bilinear interpolation
%
% Chapter  5:  Root Finding
%
%   bisect   => bisection root-finding method
%   falsepos => false position root-finding method
%   aitken   => contraction mapping method with Aitken extrapolation
%   secant   => secant root-finding method
%   muller   => Muller root-finding method 
%   jacobian => jacobian matrix of partial derivatives
%   newton   => Newton method for nonlinear algebraic systems
%   roots    => roots of polynomial using QR method (built-in) 
%
% Chapter  6:  Optimization
%
%   bracket  => find three-point pattern
%   golden   => golden section line search
%   conjgrad => conjugate gradient unconstrained minimization
%   dfp      => Davidon-Fletcher-Powell unconstrained minimization
%   penalty  => penalty function constrained minimization
%   fmu      => generalized objective function
%   gradfmu  => gradient of generalized objective function
%   anneal   => global minimization by simulated annealing  
%   funannea => equality constraint for simulated annealing
% 
% Chapter  7:  Differentiation and Integration
%
%   deriv    => first order numerical derivatives
%   deriv2   => second order numerical derivatives
%   trapint  => trapezoid rule integration
%   simpson  => Simpson 1/3 rule integration
%   midpoint => midpoint rule integration
%   romberg  => Romberg variable order integration
%   gausquad => Gaussian quadrature integration 
%   monte    => Monte Carlo multi-dimensional integration 
%  
% Chapter  8:  Ordinary Differential Equations (ODE)
%
%   rkfstep  => Runge-Kutta-Fehlberg fourth-fifth order step
%   rkf0     => Runge-Kutta-Fehlberg variable step size method
%   rkf      => Runge-Kutta-Fehlberg variable step size driver
%   predcorr => predictor-corrector multistep method
%   bsext0   => Bulirsch-Stoer variable order extrapolation method
%   bsext    => Bulirsch-Stoer variable order extrapolation driver
%   stiff0   => Semi-implicit extrapolation method for stiff systems
%   stiff    => Semi-implicit extrapolation driver for stiff systems
%   ftstiff  => partial derivatives with respect to t
%   fxstiff  => partial derivatives with respect to x
%   bvp      => two-point boundary value problem solver
%
% Chapter  9:  Partial Differential Equations (PDE)
%
%   poisson  => Poisson/Laplace equation  
%   heat1    => one-dimensional heat/diffusion equation
%   heat2    => two-dimensional heat/diffusion equation
%   wave1    => one-dimensional wave equation
%   wave2    => two-dimensional wave equation
%       
% Chapter 10:  Digital Signal Processing (DSP)
%
%   dft      => fast Fourier transform (FFT)
%   dft2     => two-dimensional FFT
%   spectra  => magnitude spectrum of a signal 
%   convolve => discrete convolution of two signals
%   crosscor => normalized cross correlation of two signals
%   fir      => FIR digital filter design
%   freqrsp  => frequency response from input and output signals
%   arma     => auto-regressive moving average (ARMA) model
%   getarma  => identify ARMA model using least squares fit
%   lms      => adaptive least-squares identification of MA model  
%----------------------------------------------------------------------
more on
help nlib
more off
%----------------------------------------------------------------------


