function plotfun (x0,x1,y0,y1,caption,xaxis,yaxis,zaxis,f)
%----------------------------------------------------------------
% Usage:       plotfun (x0,x1,y0,y1,caption,xaxis,yaxis,zaxis,f)
%
% Description: Plot the function f as a surface
%
% Inputs:      x0      = lower limit for first independent variable 
%              x1      = upper limit for first independent variable 
%              y0      = lower limit for second independent variable 
%              y1      = upper limit for second independent variable 
%              caption = string containing graph title
%              xaxis   = string containing x-axis label
%              yaxis   = string containing y-axis label
%              zaxis   = string containing y-axis label
%              f       = string specifying function name 
%----------------------------------------------------------------
   n = 41;
   figure
   box off
   x = linspace (x0,x1,n)';
   y = linspace (y0,y1,n)';
   hwbar = waitbar (0,'Computing Surface');
   for i = 1 : n
      waitbar (i/n);
      for j = 1 : n
         Z(i,j) = feval(f,x(i),y(j));
      end
   end   
   close (hwbar);
   mesh (real(x),real(y),real(Z'))
   title (caption)
   xlabel (xaxis)
   ylabel (yaxis)
   zlabel (zaxis)
   wait
%----------------------------------------------------------------

