function y = polynom (a,x)
%----------------------------------------------------------------
% Usage:       y = polynom (a,x)
%
% Description: Evaluate a polynomial using Horner's rule.
%
% Inputs:      a = n+1 by 1 coefficient vector
%              x = evaluaton point
%
% Outputs:     y = a(1) + a(2)*x + ... + a(n+1)*x^n
%
% Note:        The coefficient vector a is in REVERSE ORDER from
%              the one used in the Matlab function polyval.
%----------------------------------------------------------------
   chkvec (a,1,'polynom');
   n = length(a) - 1;
   y = a(n+1);
   for i = n : -1 : 1
      y = y.*x + a(i); 
   end
%----------------------------------------------------------------
