function putmat (A,vname,fname,mode)
%----------------------------------------------------------------------
% Usage:       putmat (A,vname,fname,mode)
%
% Description: Save a matrix to a disk file
%
% Inputs:      A     = m by n matrix to be written
%              vname = variable name to be used for A
%              fname = file name 
%              mode  = writing mode (0 = append, 1 = overwrite) 
%----------------------------------------------------------------------

% Add extension .m to file name

   i = 1;
   s = fname;
   while (i <= length(s)) & (s(i) ~= '.')
      i = i + 1;
   end
   s(i:i+1) = '.m';
   r = s(1:i+1);

% Open file

   if mode
      f = fopen (r,'w');
   else
      f = fopen (r,'a');
   end
   if f == -1 
      fprintf ('\nputmat was unable to open file %s.',fname)
      return
   end

   [m,n] = size(A);
   if isreal(A)

% Write real matrix      

      fprintf (f,'%s = [\n',vname);   
      for i = 1 : m
         for j = 1 : n
            if (mod(j,7) == 0) & (j < n)
               fprintf (f,'%g ...\n',A(i,j));
            elseif j < n 
               fprintf (f,'%g ',A(i,j));
            elseif i < m 
               fprintf (f,'%g\n',A(i,j));
            else
               fprintf (f,'%g\n];\n',A(i,j));
            end
         end
      end

   else

% Write complex matrix      

      fprintf (f,'%s = [\n',vname);   
      for i = 1 : m
         for j = 1 : n
            if (mod(j,7) == 0) & (j < n)
               fprintf (f,'%g%+gi ...\n',real(A(i,j)),imag(A(i,j)));
            elseif j < n 
               fprintf (f,'%g%+gi ',real(A(i,j)),imag(A(i,j)));
            elseif i < m
               fprintf (f,'%g%+gi\n',real(A(i,j)),imag(A(i,j)));
            else         
               fprintf (f,'%g%+gi\n];\n',real(A(i,j)),imag(A(i,j)));
            end
         end
      end
   end
   fclose (f);
%----------------------------------------------------------------------
