function [x,y] = pictex (f,a,b,n,scale,offset,shade,g)
%-----------------------------------------------------------------------
% Usage:       [x,y] = pictex (f,a,b,n,scale,offset,shade,g) 
%
% Description: Generate n points of f(x) uniformly distributed over
%              [a,b] for use with PicTex.  Use specified scale and
%              offset vectors.  If shade is true, use shadding.  
%              Store the results in the file g.
%-----------------------------------------------------------------------

% Initialize

dx = (b - a)/(n - 1);
fid = fopen (g,'w');
fprintf (fid,'\\plot ');

% Create plot command

for k = 1 : n
   c = a + (k-1)*dx;
   x(k) = scale(1)*c + offset(1);
   y(k) = scale(2)*feval(f,c) + offset(2);
   fprintf (fid,'%g %g ',x(k),y(k));
end
fprintf (fid,'/\n');

% Create shade command

if shade
   fprintf (fid,'\\vshade ');
   for k = 1 : n
      fprintf (fid,'%g %g %g ',x(k),0,y(k));
   end
   fprintf (fid,'/\n');
end   

fclose(fid);
