function [x,Delta] = tridec (T,b)
%----------------------------------------------------------------------
% Usage:      [x,Delta] = tridec (T,b)
%
% Descripton: Solve an n dimensional tridiagonal linear system Ax = b
%
% Inputs:     T = 3 by n matrix containing the nonzero entries of A:
%
%                 row                  contents
%                 ---------------------------------------------------
%                  1     A[1][2], A[2][3], ... , A[n-1][n],   ---    
%                  1     A[1][1], A[2][2], ... , A[n-1][n-1], A[n][n]    
%                  3     A[2][1], A[3][2], ... , A[n][n-1],   ---    
%                 ---------------------------------------------------
%
%             b = n by 1 right-hand side vector
% 
% Outputs:    x     = n by 1 solution vector 
%             Delta = deteriminant of A.  If Delta ~= 0, x is valid.
%----------------------------------------------------------------------
   chkvec (b,2,'tridec');
   [Q,Delta] = trifac (T);
   [x,Delta] = trisub (Q,b);
%----------------------------------------------------------------
